@@ -3,7 +3,7 @@
 '''
 This module provides various representations of transformed structures. A
 TransformedStructure is a structure that has been modified by undergoing a
-series of transformations. 
+series of transformations.
 '''
 
 from __future__ import division
@@ -31,8 +31,9 @@ from pymatgen.serializers.json_coders import MSONable
 
 class TransformedStructure(MSONable):
     """
-    Container object for new structures that include history of transformations.
-    
+    Container object for new structures that include history of
+    transformations.
+
     Each transformed structure is made up of a sequence of structures with
     associated transformation history.
     """
@@ -41,20 +42,20 @@ class TransformedStructure(MSONable):
                  other_parameters=None):
         """
         Standard constructor for a TransformedStructure.
-        
+
         Args:
             structure:
                 input structure
             transformations:
-                Sequence of transformations to be applied to the input 
+                Sequence of transformations to be applied to the input
                 structure.
             history:
                 optional history for the input structure, which provides a way
-                to track structures having undergone multiple series of 
+                to track structures having undergone multiple series of
                 transformations.
             other_parameters:
-                optional parameters to store along with the 
-                TransformedStructure. This can include tags (a list) or author 
+                optional parameters to store along with the
+                TransformedStructure. This can include tags (a list) or author
                 which will be parsed.
         """
         history = [] if history == None else history
@@ -63,13 +64,17 @@ class TransformedStructure(MSONable):
         self._transformations = []
         self._transformation_parameters = []
         self._redo_trans = []
-        self._other_parameters = {} if other_parameters == None else deepcopy(other_parameters)
+        self._other_parameters = {} if other_parameters is None \
+            else deepcopy(other_parameters)
         if len(history) > 0:
             self._source = history[0]
             for i in xrange(1, len(history)):
-                self._structures.append(Structure.from_dict(history[i]['input_structure']))
-                self._transformations.append(AbstractTransformation.from_dict(history[i]))
-                self._transformation_parameters.append(history[i].get('output_parameters', {}))
+                struct = Structure.from_dict(history[i]['input_structure'])
+                trans = AbstractTransformation.from_dict(history[i])
+                param = history[i].get('output_parameters', {})
+                self._structures.append(struct)
+                self._transformations.append(trans)
+                self._transformation_parameters.append(param)
 
         self._structures.append(structure)
         for t in transformations:
@@ -78,7 +83,7 @@ class TransformedStructure(MSONable):
     def undo_last_transformation(self):
         """
         Undo the last transformation in the TransformedStructure.
-        
+
         Raises:
             IndexError if already at the oldest change.
         """
@@ -91,7 +96,7 @@ class TransformedStructure(MSONable):
     def redo_next_transformation(self):
         """
         Redo the last undone transformation in the TransformedStructure.
-        
+
         Raises:
             IndexError if already at the latest change.
         """
@@ -113,7 +118,7 @@ class TransformedStructure(MSONable):
                               clear_redo=True):
         """
         Appends a transformation to the TransformedStructure.
-        
+
         Args:
             transformation:
                 Transformation to append
@@ -124,9 +129,10 @@ class TransformedStructure(MSONable):
                 return.
             clear_redo:
                 Boolean indicating whether to clear the redo list. By default,
-                this is True, meaning any appends clears the history of undoing.
-                However, when using append_transformation to do a redo, the redo
-                list should not be cleared to allow multiple redos.
+                this is True, meaning any appends clears the history of
+                undoing. However, when using append_transformation to do a
+                redo, the redo list should not be cleared to allow multiple
+                redos.
         """
         if clear_redo:
             self._redo_trans = []
@@ -146,8 +152,10 @@ class TransformedStructure(MSONable):
                 tdict['input_structure'] = starting_struct.to_dict
                 tdict['output_parameters'] = x
                 hist.append(tdict)
-                alts.append(TransformedStructure(struct, [], history=hist, other_parameters=other_paras))
-            #use the first item in the ranked_list and apply it to this transformed_structure
+                alts.append(TransformedStructure(struct, [], history=hist,
+                                                 other_parameters=other_paras))
+            #use the first item in the ranked_list and apply it to this
+            #transformed_structure
             x = ranked_list[0]
             struct = x.pop('structure')
             actual_transformation = x.pop('transformation', transformation)
@@ -164,7 +172,7 @@ class TransformedStructure(MSONable):
     def extend_transformations(self, transformations):
         """
         Extends a sequence of transformations to the TransformedStructure.
-        
+
         Args:
             transformations:
                 Sequence of Transformations
@@ -175,34 +183,37 @@ class TransformedStructure(MSONable):
     def get_vasp_input(self, vasp_input_set, generate_potcar=True):
         """
         Returns VASP input as a dict of vaspio objects.
-        
+
         Args:
             vasp_input_set:
                 pymatgen.io.vaspio_set.VaspInputSet like object that creates
                 vasp input files from structures
             generate_potcar:
-                Set to False to generate a POTCAR.spec file instead of a POTCAR,
-                which contains the POTCAR labels but not the actual POTCAR.
-                Defaults to True.
+                Set to False to generate a POTCAR.spec file instead of a
+                POTCAR, which contains the POTCAR labels but not the actual
+                POTCAR. Defaults to True.
         """
-        d = vasp_input_set.get_all_vasp_input(self._structures[-1], generate_potcar)
+        d = vasp_input_set.get_all_vasp_input(self._structures[-1],
+                                              generate_potcar)
         d['transformations.json'] = json.dumps(self.to_dict)
         return d
 
-    def write_vasp_input(self, vasp_input_set, output_dir, create_directory=True):
+    def write_vasp_input(self, vasp_input_set, output_dir,
+                         create_directory=True):
         """
         Writes VASP input to an output_dir.
-        
+
         Args:
             vasp_input_set:
-                pymatgen.io.vaspio_set.VaspInputSet like object that creates 
+                pymatgen.io.vaspio_set.VaspInputSet like object that creates
                 vasp input files from structures
             output_dir:
                 Directory to output files
             create_directory:
                 Create the directory if not present. Defaults to True.
         """
-        vasp_input_set.write_input(self._structures[-1], output_dir, make_dir_if_not_present=create_directory)
+        vasp_input_set.write_input(self._structures[-1], output_dir,
+                                   make_dir_if_not_present=create_directory)
         with open(os.path.join(output_dir, 'transformations.json'), 'w') as fp:
             json.dump(self.to_dict, fp)
 
@@ -216,7 +227,8 @@ class TransformedStructure(MSONable):
         output.append("\nTransformation history")
         output.append("------------")
         for i, t in enumerate(self._transformations):
-            output.append("{} {}".format(t.to_dict, self._transformation_parameters[i]))
+            output.append("{} {}".format(t.to_dict,
+                                         self._transformation_parameters[i]))
         output.append("\nOther parameters")
         output.append("------------")
         output.append(str(self._other_parameters))
@@ -232,7 +244,7 @@ class TransformedStructure(MSONable):
     @property
     def was_modified(self):
         """
-        Boolean describing whether the last transformation on the structure 
+        Boolean describing whether the last transformation on the structure
         made any alterations to it one example of when this would return false
         is in the case of performing a substitution transformation on the
         structure when the specie to replace isn't in the structure.
@@ -242,7 +254,7 @@ class TransformedStructure(MSONable):
     @property
     def structures(self):
         """
-        Returns a copy of all structures in the TransformedStructure. A 
+        Returns a copy of all structures in the TransformedStructure. A
         structure is stored after every single transformation.
         """
         return [s for s in self._structures]
@@ -250,7 +262,7 @@ class TransformedStructure(MSONable):
     @property
     def transformations(self):
         """
-        Returns a copy of all transformations in the TransformedStructure. 
+        Returns a copy of all transformations in the TransformedStructure.
         """
         return [t for t in self._transformations]
 
@@ -267,7 +279,8 @@ class TransformedStructure(MSONable):
         Creates a TransformedStructure from a dict.
         """
         s = Structure.from_dict(d)
-        return TransformedStructure(s, [], d['history'], d.get('other_parameters', None))
+        return TransformedStructure(s, [], d['history'],
+                                    d.get('other_parameters', None))
 
     @property
     def history(self):
@@ -326,13 +339,16 @@ class TransformedStructure(MSONable):
             source = partial_cif['_database_code_ICSD'] + "-ICSD"
         else:
             source = 'uploaded cif'
-        source_info = {'source':source, 'datetime':str(datetime.datetime.now()), 'original_file':raw_string, 'cif_data':cif_dict[cif_keys[0]]}
+        source_info = {'source': source,
+                       'datetime': str(datetime.datetime.now()),
+                       'original_file': raw_string,
+                       'cif_data': cif_dict[cif_keys[0]]}
         return TransformedStructure(s, transformations, [source_info])
 
     @staticmethod
     def from_poscar_string(poscar_string, transformations=[]):
         """
-        Generates TransformedStructure from a poscar string. 
+        Generates TransformedStructure from a poscar string.
 
         Args:
             poscar_string:
@@ -340,10 +356,11 @@ class TransformedStructure(MSONable):
         """
         p = Poscar.from_string(poscar_string)
         if not p.true_names:
-            raise ValueError("Transformation can be craeted only from POSCAR strings with proper VASP5 element symbols.")
+            raise ValueError("Transformation can be craeted only from POSCAR "
+                             "strings with proper VASP5 element symbols.")
         raw_string = re.sub("'", "\"", poscar_string)
         s = p.structure
-        source_info = {'source': "uploaded POSCAR", 'datetime':str(datetime.datetime.now()), 'original_file':raw_string}
+        source_info = {'source': "uploaded POSCAR",
+                       'datetime': str(datetime.datetime.now()),
+                       'original_file': raw_string}
         return TransformedStructure(s, transformations, [source_info])
-
-
