@@ -29,43 +29,45 @@ from pymatgen.core.structure import Structure
 class EwaldSummation(object):
     """
     Calculates the electrostatic energy of a periodic array of charges using
-    the Ewald technique. 
+    the Ewald technique.
     Ref: http://www.ee.duke.edu/~ayt/ewaldpaper/ewaldpaper.html
-    
+
     This matrix can be used to do fast calculations of ewald sums after species
     removal.
-    
+
     E = E_recip + E_real + E_point
-    
+
     Atomic units used in the code, then converted to eV.
     """
 
-    # Converts unit of q*q/r into eV 
+    # Converts unit of q*q/r into eV
     CONV_FACT = 1e10 * ELECTRON_CHARGE / (4 * pi * EPSILON_0)
 
     def __init__(self, structure, real_space_cut=None, recip_space_cut=None,
                  eta=None, acc_factor=8.0):
         """
-        Initializes and calculates the Ewald sum. Default convergence parameters
-        have been specified, but you can override them if you wish.
-        
+        Initializes and calculates the Ewald sum. Default convergence
+        parameters have been specified, but you can override them if you wish.
+
         Args:
-            structure: 
+            structure:
                 input structure that must have proper Specie on all sites, i.e.
-                Element with oxidation state. Use OxidationStateDecorator in 
+                Element with oxidation state. Use
+                StructureEditor.add_oxidation_state... in
                 pymatgen.core.structure_modifier for example.
-            real_space_cut: 
+            real_space_cut:
                 Real space cutoff radius dictating how many terms are used in
                 the real space sum. Defaults to None, which means determine
-                automagically using the formula given in gulp 3.1 documentation.
-            recip_space_cut: 
+                automagically using the formula given in gulp 3.1
+                documentation.
+            recip_space_cut:
                 Reciprocal space cutoff radius. Defaults to None, which means
                 determine automagically using the formula given in gulp 3.1
                 documentation.
-            eta: 
+            eta:
                 The screening parameter. Defaults to None, which means
                 determine automatically.
-            acc_factor: 
+            acc_factor:
                 No. of significant figures each sum is converged to.
         """
         self._s = structure
@@ -74,22 +76,26 @@ class EwaldSummation(object):
         self._acc_factor = acc_factor
 
         # set screening length
-        self._eta = eta if eta else (len(structure) * 0.01 / self._vol) ** (1 / 3) * pi
+        self._eta = eta if eta \
+            else (len(structure) * 0.01 / self._vol) ** (1 / 3) * pi
         self._sqrt_eta = sqrt(self._eta)
 
-        # acc factor used to automatically determine the optimal real and 
+        # acc factor used to automatically determine the optimal real and
         # reciprocal space cutoff radii
         self._accf = sqrt(log(10 ** acc_factor))
 
-        self._rmax = real_space_cut if real_space_cut else self._accf / self._sqrt_eta
-        self._gmax = recip_space_cut if recip_space_cut else 2 * self._sqrt_eta * self._accf
+        self._rmax = real_space_cut if real_space_cut \
+            else self._accf / self._sqrt_eta
+        self._gmax = recip_space_cut if recip_space_cut \
+            else 2 * self._sqrt_eta * self._accf
 
         """
         The next few lines pre-compute certain quantities and store them. Ewald
         summation is rather expensive, and these shortcuts are necessary to
         obtain several factors of improvement in speedup.
         """
-        self._oxi_states = [compute_average_oxidation_state(site) for site in structure]
+        self._oxi_states = [compute_average_oxidation_state(site)
+                            for site in structure]
         self._coords = np.array(self._s.cart_coords)
         self._forces = np.zeros((len(structure), 3))
 
@@ -98,13 +104,14 @@ class EwaldSummation(object):
         and real space terms.
         """
         (self._recip, recip_forces) = self._calc_recip()
-        (self._real, self._point, real_point_forces) = self._calc_real_and_point()
+        (self._real, self._point, real_point_forces) = \
+            self._calc_real_and_point()
         self._forces = recip_forces + real_point_forces
 
     def compute_partial_energy(self, removed_indices):
         """
         Gives total ewald energy for certain sites being removed, i.e. zeroed
-        out. 
+        out.
         """
         total_energy_matrix = self.total_energy_matrix.copy()
         for i in removed_indices:
@@ -112,18 +119,28 @@ class EwaldSummation(object):
             total_energy_matrix[:, i] = 0
         return sum(sum(total_energy_matrix))
 
-    def compute_sub_structure(self, structure):
+    def compute_sub_structure(self, sub_structure, tol=1e-3):
         """
-        Gives total ewald energy for an sub structure in the same 
-        lattice. The sub structure must be a subset of the original
+        Gives total ewald energy for an sub structure in the same
+        lattice. The sub_structure must be a subset of the original
         structure, with possible different charges.
+
+        Args:
+            substructure:
+                Substructure to compute Ewald sum for.
+            tol:
+                Tolerance for site matching in fractional coordinates.
+
+        Returns:
+            Ewald sum of substructure.
         """
         total_energy_matrix = self.total_energy_matrix.copy()
 
         def find_match(site):
-            for test_site in structure:
-                frac_diff = abs(np.array(site.frac_coords) - np.array(test_site.frac_coords)) % 1
-                frac_diff = [abs(a) < 1e-5 or abs(a) > 1 - 1e-5 \
+            for test_site in sub_structure:
+                frac_diff = abs(np.array(site.frac_coords)
+                                - np.array(test_site.frac_coords)) % 1
+                frac_diff = [abs(a) < tol or abs(a) > 1 - tol \
                      for a in frac_diff]
                 if all(frac_diff):
                     return test_site
@@ -142,11 +159,12 @@ class EwaldSummation(object):
             total_energy_matrix[i, :] *= scaling_factor
             total_energy_matrix[:, i] *= scaling_factor
 
-        if len(matches) != len(structure):
+        if len(matches) != len(sub_structure):
             print "Missing sites."
             print len(matches)
-            print len(structure)
-            print "unmatched = {}".format([site for site in structure if site not in matches])
+            print len(sub_structure)
+            print "unmatched = {}".format([site for site in sub_structure
+                                           if site not in matches])
 
         return sum(sum(total_energy_matrix))
 
@@ -160,7 +178,7 @@ class EwaldSummation(object):
     @property
     def reciprocal_space_energy_matrix(self):
         """
-        The reciprocal space energy matrix. Each matrix element (i, j) 
+        The reciprocal space energy matrix. Each matrix element (i, j)
         corresponds to the interaction energy between site i and site j in
         reciprocal space.
         """
@@ -217,25 +235,29 @@ class EwaldSummation(object):
     @property
     def forces(self):
         """
-        The forces on each site as a Nx3 matrix. Each row corresponds to a site.
+        The forces on each site as a Nx3 matrix. Each row corresponds to a
+        site.
         """
         return self._forces
 
     def _calc_recip(self):
         """
         Perform the reciprocal space summation. Calculates the quantity
-        E_recip = 1/(2PiV) sum_{G < Gmax} exp(-(G.G/4/eta))/(G.G) S(G)S(-G) where
+        E_recip = 1/(2PiV) sum_{G < Gmax} exp(-(G.G/4/eta))/(G.G) S(G)S(-G)
+        where
         S(G) = sum_{k=1,N} q_k exp(-i G.r_k)
         S(G)S(-G) = |S(G)|**2
-        
-        This method is heavily vectorized to utilize numpy's C backend for speed.
+
+        This method is heavily vectorized to utilize numpy's C backend for
+        speed.
         """
         numsites = self._s.num_sites
         prefactor = 2 * pi / self._vol
         erecip = np.zeros((numsites, numsites))
         forces = np.zeros((numsites, 3))
         coords = self._coords
-        recip = Structure(self._s.lattice.reciprocal_lattice, ["H"], [np.array([0, 0, 0])])
+        recip = Structure(self._s.lattice.reciprocal_lattice, ["H"],
+                          [np.array([0, 0, 0])])
         recip_nn = recip.get_neighbors(recip[0], self._gmax)
 
         for (n, dist) in recip_nn:
@@ -265,26 +287,27 @@ class EwaldSummation(object):
                     sfactor[i, j] = qi * qj * (cosa + sina)
                     """
                     Uses the property that when site i and site j are switched,
-                    exparg' == - exparg. This implies 
+                    exparg' == - exparg. This implies
                     cos (exparg') = cos (exparg) and
                     sin (exparg') = - sin (exparg)
-                    
+
                     Halves all computations.
                     """
                     sfactor[j, i] = qi * qj * (cosa - sina)
 
             erecip += expval / gsquare * sfactor
             pref = 2 * expval / gsquare * np.array(self._oxi_states)
-            factor = prefactor * pref * (sreal * np.sin(gvectdot) - simag * np.cos(gvectdot)) * EwaldSummation.CONV_FACT
+            factor = prefactor * pref * \
+                (sreal * np.sin(gvectdot)
+                 - simag * np.cos(gvectdot)) * EwaldSummation.CONV_FACT
             forces += np.tile(factor, (3, 1)).transpose() * gvect_tile
 
-        return (erecip * prefactor * EwaldSummation.CONV_FACT , forces)
-
+        return (erecip * prefactor * EwaldSummation.CONV_FACT, forces)
 
     def _calc_real_and_point(self):
         """
         Determines the self energy -(eta/pi)**(1/2) * sum_{i=1}^{N} q_i**2
-        
+
         If cell is charged a compensating background is added (i.e. a G=0 term)
         """
         all_nn = self._s.get_all_neighbors(self._rmax, True)
@@ -296,19 +319,22 @@ class EwaldSummation(object):
         epoint = np.zeros((numsites))
         forces = np.zeros((numsites, 3))
         for i in xrange(numsites):
-            nn = all_nn[i] #self._s.get_neighbors(site, self._rmax)
+            nn = all_nn[i]  # self._s.get_neighbors(site, self._rmax)
             qi = self._oxi_states[i]
             epoint[i] = qi * qi
             epoint[i] *= -1.0 * sqrt(self._eta / pi)
-            epoint[i] += qi * pi / (2.0 * self._vol * self._eta)  #add jellium term
-            for j in range(len(nn)):  #for (nsite, rij)  in nn:
+            # add jellium term
+            epoint[i] += qi * pi / (2.0 * self._vol * self._eta)
+            for j in range(len(nn)):
                 nsite = nn[j][0]
                 rij = nn[j][1]
                 qj = compute_average_oxidation_state(nsite)
                 erfcval = erfc(self._sqrt_eta * rij)
                 ereal[nn[j][2], i] += erfcval * qi * qj / rij
-                fijpf = qj / pow(rij, 3) * (erfcval + forcepf * rij * exp(-self._eta * pow(rij, 2)))
-                forces[i] += fijpf * (coords[i] - nsite.coords) * qi * EwaldSummation.CONV_FACT
+                fijpf = qj / pow(rij, 3) * (erfcval + forcepf * rij *
+                                            exp(-self._eta * pow(rij, 2)))
+                forces[i] += fijpf * (coords[i] - nsite.coords) * \
+                    qi * EwaldSummation.CONV_FACT
 
         ereal = ereal * 0.5 * EwaldSummation.CONV_FACT
         epoint = epoint * EwaldSummation.CONV_FACT
@@ -329,19 +355,19 @@ class EwaldSummation(object):
 
 class EwaldMinimizer:
     '''
-    This class determines the manipulations that will minimize an ewald matrix, 
-    given a list of possible manipulations. This class does not perform the 
-    manipulations on a structure, but will return the list of manipulations that 
-    should be done on one to produce the minimal structure. It returns the 
-    manipulations for the n lowest energy orderings. This class should be used 
-    to perform fractional species substitution or fractional species removal to 
-    produce a new structure. These manipulations create large numbers of 
-    candidate structures, and this class can be used to pick out those with the 
+    This class determines the manipulations that will minimize an ewald matrix,
+    given a list of possible manipulations. This class does not perform the
+    manipulations on a structure, but will return the list of manipulations
+    that should be done on one to produce the minimal structure. It returns the
+    manipulations for the n lowest energy orderings. This class should be used
+    to perform fractional species substitution or fractional species removal to
+    produce a new structure. These manipulations create large numbers of
+    candidate structures, and this class can be used to pick out those with the
     lowest ewald sum.
-    
-    An alternative (possibly more intuitive) interface to this class is the 
+
+    An alternative (possibly more intuitive) interface to this class is the
     order disordered structure transformation.
-    
+
     Author - Will Richards
     '''
 
@@ -359,33 +385,38 @@ class EwaldMinimizer:
     def __init__(self, matrix, m_list, num_to_return=1, algo=ALGO_FAST):
         '''
         Args:
-            matrix:      
-                a matrix of the ewald sum interaction energies. This is stored 
-                in the class as a diagonally symmetric array and so self._matrix 
-                will not be the same as the input matrix
+            matrix:
+                a matrix of the ewald sum interaction energies. This is stored
+                in the class as a diagonally symmetric array and so
+                self._matrix will not be the same as the input matrix.
             m_list:
-                list of manipulations. each item is of the form 
+                list of manipulations. each item is of the form
                 (multiplication fraction, number_of_indices, indices, species)
-                These are sorted such that the first manipulation contains the 
-                most permutations. this is actually evaluated last in the 
+                These are sorted such that the first manipulation contains the
+                most permutations. this is actually evaluated last in the
                 recursion since I'm using pop.
-            num_to_return: 
-                The minimizer will find the number_returned lowest energy 
-                structures. This is likely to return a number of duplicate 
-                structures so it may be necessary to overestimate and then 
-                remove the duplicates later. (duplicate checking in this 
+            num_to_return:
+                The minimizer will find the number_returned lowest energy
+                structures. This is likely to return a number of duplicate
+                structures so it may be necessary to overestimate and then
+                remove the duplicates later. (duplicate checking in this
                 process is extremely expensive)
         '''
-        #setup and checking of inputs
+        # Setup and checking of inputs
         self._matrix = copy(matrix)
-        for i in range(len(self._matrix)): #make the matrix diagonally symmetric (so matrix[i,:] == matrix[:,j])
+        # Make the matrix diagonally symmetric (so matrix[i,:] == matrix[:,j])
+        for i in range(len(self._matrix)):
             for j in range(i, len(self._matrix)):
                 value = (self._matrix[i, j] + self._matrix[j, i]) / 2
                 self._matrix[i, j] = value
                 self._matrix[j, i] = value
+
         def comb(n, k):
             return factorial(n) / factorial(k) / factorial(n - k)
-        self._m_list = sorted(m_list, key=lambda x: comb(len(x[2]), x[1]), reverse=True) #sort the m_list based on number of permutations
+
+        # sort the m_list based on number of permutations
+        self._m_list = sorted(m_list, key=lambda x: comb(len(x[2]), x[1]),
+                              reverse=True)
 
         for mlist in self._m_list:
             if mlist[0] > 1:
@@ -394,11 +425,13 @@ class EwaldMinimizer:
         self._num_to_return = num_to_return
         self._algo = algo
         if algo == EwaldMinimizer.ALGO_COMPLETE:
-            raise NotImplementedError('Complete algo not yet implemented for EwaldMinimizer')
+            raise NotImplementedError('Complete algo not yet implemented for '
+                                      'EwaldMinimizer')
 
         self._output_lists = []
-
-        self._finished = False #tag that the recurse function looks at at each level. If a method sets this to true it breaks the recursion and stops the search
+        # Tag that the recurse function looks at at each level. If a method
+        # sets this to true it breaks the recursion and stops the search.
+        self._finished = False
 
         self._start_time = datetime.utcnow()
 
@@ -409,41 +442,44 @@ class EwaldMinimizer:
 
     def minimize_matrix(self):
         '''
-        This method finds and returns the permutations that produce the lowest ewald sum
-        calls recursive function to iterate through permutations
+        This method finds and returns the permutations that produce the lowest
+        ewald sum calls recursive function to iterate through permutations
         '''
-        if self._algo == EwaldMinimizer.ALGO_FAST or self._algo == EwaldMinimizer.ALGO_BEST_FIRST:
-            return self._recurse(self._matrix, self._m_list, set(range(len(self._matrix))))
-
+        if self._algo == EwaldMinimizer.ALGO_FAST or \
+            self._algo == EwaldMinimizer.ALGO_BEST_FIRST:
+            return self._recurse(self._matrix, self._m_list,
+                                 set(range(len(self._matrix))))
 
     def add_m_list(self, matrix_sum, m_list):
         '''
-        This adds an m_list to the output_lists and updates the current minimum if the list is full.
+        This adds an m_list to the output_lists and updates the current
+        minimum if the list is full.
         '''
         if self._output_lists is None:
             self._output_lists = [[matrix_sum, m_list]]
         else:
             bisect.insort(self._output_lists, [matrix_sum, m_list])
-        if self._algo == EwaldMinimizer.ALGO_BEST_FIRST and len(self._output_lists) == self._num_to_return:
+        if self._algo == EwaldMinimizer.ALGO_BEST_FIRST and \
+            len(self._output_lists) == self._num_to_return:
             self._finished = True
         if len(self._output_lists) > self._num_to_return:
             self._output_lists.pop()
         if len(self._output_lists) == self._num_to_return:
             self._current_minimum = self._output_lists[-1][0]
 
-
     def best_case(self, matrix, m_list, indices_left):
         '''
         Computes a best case given a matrix and manipulation list.
-        
+
         Args:
-            matrix: 
+            matrix:
                 the current matrix (with some permutations already performed
-            m_list: 
-                [(multiplication fraction, number_of_indices, indices, species) ]
-                describing the manipulation
-            indices: 
-                set of indices which haven't had a permutation performed on them 
+            m_list:
+                [(multiplication fraction, number_of_indices, indices,
+                species)] describing the manipulation
+            indices:
+                Set of indices which haven't had a permutation performed on
+                them.
         '''
 
         m_indices = []
@@ -460,14 +496,15 @@ class EwaldMinimizer:
         fractions[:len(fraction_list)] = fraction_list
         fractions = np.sort(fractions)
 
-        #sum associated with each index (disregarding interactions between indices)
+        # Sum associated with each index (disregarding interactions between
+        # indices)
         sums = 2 * np.sum(matrix[indices], axis=1)
         sums = np.sort(sums)
 
-        #interaction corrections. Can be reduced to (1-x)(1-y) for x,y in fractions
-        #each element in a column gets multiplied by (1-x), and then the sum of the columns gets 
-        #multiplied by (1-y)
-        #since fractions are less than 1, there is no effect of one choice on the other
+        # Interaction corrections. Can be reduced to (1-x)(1-y) for x,y in
+        # fractions each element in a column gets multiplied by (1-x), and then
+        # the sum of the columns gets multiplied by (1-y) since fractions are
+        # less than 1, there is no effect of one choice on the other
         step1 = np.sort(interaction_matrix) * (1 - fractions)
         step2 = np.sort(np.sum(step1, axis=1))
         step3 = step2 * (1 - fractions)
@@ -480,14 +517,19 @@ class EwaldMinimizer:
             avg_frac = np.average(np.outer(1 - fractions, 1 - fractions))
             average_correction = avg_int * avg_frac
 
-            interaction_correction = average_correction * speedup_parameter + interaction_correction * (1 - speedup_parameter)
+            interaction_correction = average_correction * speedup_parameter \
+                + interaction_correction * (1 - speedup_parameter)
 
-        best_case = np.sum(matrix) + np.inner(sums[::-1], fractions - 1) + interaction_correction
+        best_case = np.sum(matrix) + np.inner(sums[::-1], fractions - 1) \
+            + interaction_correction
 
         return best_case
 
-
-    def get_next_index(self, matrix, manipulation, indices_left): #returns an index that should have the most negative effect on the matrix sum
+    def get_next_index(self, matrix, manipulation, indices_left):
+        """
+        Returns an index that should have the most negative effect on the
+        matrix sum
+        """
         f = manipulation[0]
         indices = list(indices_left.intersection(manipulation[2]))
         sums = np.sum(matrix[indices], axis=1)
@@ -500,25 +542,28 @@ class EwaldMinimizer:
 
     def _recurse(self, matrix, m_list, indices, output_m_list=[]):
         '''
-        This method recursively finds the minimal permutations using a binary tree search strategy
-        
+        This method recursively finds the minimal permutations using a binary
+        tree search strategy.
+
         Args:
-            matrix: 
+            matrix:
                 The current matrix (with some permutations already performed
-            m_list: 
+            m_list:
                 The list of permutations still to be performed
-            indices: 
-                Set of indices which haven't had a permutation performed on them
+            indices:
+                Set of indices which haven't had a permutation performed on
+                them.
         '''
         #check to see if we've found all the solutions that we need
         if self._finished:
             return
 
-        #if we're done with the current manipulation, pop it off. 
+        #if we're done with the current manipulation, pop it off.
         while m_list[-1][1] == 0:
             m_list = copy(m_list)
             m_list.pop()
-            if not m_list: #if there are no more manipulations left to do check the value
+            #if there are no more manipulations left to do check the value
+            if not m_list:
                 matrix_sum = np.sum(matrix)
                 if matrix_sum < self._current_minimum:
                     self.add_m_list(matrix_sum, output_m_list)
@@ -536,7 +581,8 @@ class EwaldMinimizer:
 
         m_list[-1][2].remove(index)
 
-        #make the matrix and new m_list where we do the manipulation to the index that we just got
+        # Make the matrix and new m_list where we do the manipulation to the
+        # index that we just got
         matrix2 = np.copy(matrix)
         m_list2 = deepcopy(m_list)
         output_m_list2 = copy(output_m_list)
@@ -553,7 +599,6 @@ class EwaldMinimizer:
         self._recurse(matrix2, m_list2, indices2, output_m_list2)
         self._recurse(matrix, m_list, indices, output_m_list)
 
-
     @property
     def best_m_list(self):
         return self._best_m_list
@@ -570,21 +615,24 @@ class EwaldMinimizer:
 def compute_average_oxidation_state(site):
     """
     Calculates the average oxidation state of a site
-    
+
     Args:
         site:
             Site to compute average oxidation state
-        
+
     Returns:
         Average oxidation state of site.
     """
     try:
-        avg_oxi = sum([sp.oxi_state * occu for sp, occu in site.species_and_occu.items() if sp != None])
+        avg_oxi = sum([sp.oxi_state * occu
+                       for sp, occu in site.species_and_occu.items()
+                       if sp != None])
         return avg_oxi
     except:
         pass
     try:
         return site.charge
-    except AttributeError as ex:
-        raise ValueError("Ewald summation can only be performed on structures that are either oxidation state decorated or have site charges.")
-
+    except AttributeError:
+        raise ValueError("Ewald summation can only be performed on structures "
+                         "that are either oxidation state decorated or have "
+                         "site charges.")
