@@ -18,11 +18,13 @@ from pymatgen.core.periodic_table import Element
 from pymatgen.core.physical_constants import ELECTRON_TO_AMPERE_HOURS
 from pymatgen.analysis.reaction_calculator import BalancedReaction
 from pymatgen.core.structure import Composition
-from pymatgen.apps.battery.battery_abc import AbstractElectrode, AbstractVoltagePair
+from pymatgen.apps.battery.battery_abc import AbstractElectrode, \
+    AbstractVoltagePair
 from pymatgen.phasediagram.pdmaker import PhaseDiagram
 from pymatgen.phasediagram.pdanalyzer import PDAnalyzer
 from pymatgen.serializers.json_coders import PMGJSONDecoder
 
+
 class ConversionElectrode(AbstractElectrode):
     """
     Class representing a ConversionElectrode.
@@ -33,7 +35,7 @@ class ConversionElectrode(AbstractElectrode):
         General constructor for ConversionElectrode. However, it is usually
         easier to construct a ConversionElectrode using one of the static
         constructors provided.
-        
+
         Args:
             voltage_pairs:
                 The voltage pairs making up the Conversion Electrode.
@@ -45,18 +47,19 @@ class ConversionElectrode(AbstractElectrode):
         """
         self._composition = initial_comp
         self._working_ion_entry = working_ion_entry
-        self._working_ion = self._working_ion_entry.composition.elements[0].symbol
+        ion_el = self._working_ion_entry.composition.elements[0]
+        self._working_ion = ion_el.symbol
         self._vpairs = voltage_pairs
 
     @staticmethod
     def from_composition_and_pd(comp, pd, working_ion_symbol="Li"):
         """
-        Convenience constructor to make a ConversionElectrode from a composition
-        and a phase diagram.
-        
+        Convenience constructor to make a ConversionElectrode from a
+        composition and a phase diagram.
+
         Args:
             comp:
-                Starting composition for ConversionElectrode, e.g., 
+                Starting composition for ConversionElectrode, e.g.,
                 Composition("FeF3")
             pd:
                 A PhaseDiagram of the relevant system (e.g., Li-Fe-F)
@@ -69,16 +72,20 @@ class ConversionElectrode(AbstractElectrode):
         for e in pd.stable_entries:
             if e.composition.reduced_formula == comp.reduced_formula:
                 entry = e
-            elif e.is_element and e.composition.reduced_formula == working_ion_symbol:
+            elif e.is_element and \
+                e.composition.reduced_formula == working_ion_symbol:
                 working_ion_entry = e
 
         if not entry:
-            raise ValueError("Not stable compound found at composition {}.".format(comp))
+            raise ValueError("Not stable compound found at composition {}."
+                             .format(comp))
 
         analyzer = PDAnalyzer(pd)
 
         profile = analyzer.get_element_profile(working_ion, comp)
-        profile.reverse() #Need to reverse because voltage goes form most charged to most discharged
+        # Need to reverse because voltage goes form most charged to most
+        # discharged.
+        profile.reverse()
         if len(profile) < 2:
             return None
         working_ion_entry = working_ion_entry
@@ -87,19 +94,21 @@ class ConversionElectrode(AbstractElectrode):
         for el, amt in comp.items():
             if el != Element(working_ion):
                 normalization_els[el] = amt
-        vpairs = [ConversionVoltagePair.from_steps(profile[i], profile[i + 1], normalization_els) for i in xrange(len(profile) - 1)]
+        vpairs = [ConversionVoltagePair.from_steps(profile[i], profile[i + 1],
+                                                   normalization_els)
+                  for i in xrange(len(profile) - 1)]
         return ConversionElectrode(vpairs, working_ion_entry, comp)
 
     @staticmethod
     def from_composition_and_entries(comp, entries_in_chemsys,
                                      working_ion_symbol="Li"):
         """
-        Convenience constructor to make a ConversionElectrode from a composition
-        and all entries in a chemical system.
-        
+        Convenience constructor to make a ConversionElectrode from a
+        composition and all entries in a chemical system.
+
         Args:
             comp:
-                Starting composition for ConversionElectrode, e.g., 
+                Starting composition for ConversionElectrode, e.g.,
                 Composition("FeF3")
             entries_in_chemsys:
                 Sequence containing all entries in a chemical system. E.g., all
@@ -108,7 +117,8 @@ class ConversionElectrode(AbstractElectrode):
                 Element symbol of working ion. Defaults to Li.
         """
         pd = PhaseDiagram(entries_in_chemsys)
-        return ConversionElectrode.from_composition_and_pd(comp, pd, working_ion_symbol)
+        return ConversionElectrode.from_composition_and_pd(comp, pd,
+                                                           working_ion_symbol)
 
     def get_sub_electrodes(self, adjacent_only=True, include_myself=True):
         '''
@@ -118,7 +128,7 @@ class ConversionElectrode(AbstractElectrode):
         [LiTiO2 --> TiO2, LiTiO2 --> Li0.5TiO2, Li0.5TiO2 --> TiO2]
         This method can be used to return all the subelectrodes with some
         options
-        
+
         Args:
             adjacent_only:
                 Only return electrodes from compounds that are adjacent on the
@@ -126,17 +136,21 @@ class ConversionElectrode(AbstractElectrode):
                 voltage steps if this is set true
             include_myself:
                 Include this identical electrode in the list of results
-        
+
         Returns:
             A list of ConversionElectrode objects
         '''
 
         if adjacent_only:
-            return [self.__class__(self._vpairs[i:i + 1], self._working_ion_entry, self._composition) for i in xrange(len(self._vpairs))]
+            return [self.__class__(self._vpairs[i:i + 1],
+                                   self._working_ion_entry, self._composition)
+                    for i in xrange(len(self._vpairs))]
         sub_electrodes = []
         for i in xrange(len(self._vpairs)):
             for j in xrange(i, len(self._vpairs)):
-                sub_electrodes.append(self.__class__(self._vpairs[i:j + 1], self._working_ion_entry, self._composition))
+                sub_electrodes.append(self.__class__(self._vpairs[i:j + 1],
+                                                     self._working_ion_entry,
+                                                     self._composition))
         return sub_electrodes
 
     @property
@@ -170,10 +184,14 @@ class ConversionElectrode(AbstractElectrode):
         for pair1 in conversion_electrode:
             found = False
             rxn1 = pair1.rxn
-            all_formulas1 = set([rxn1.all_comp[i].reduced_formula for i in xrange(len(rxn1.all_comp)) if abs(rxn1.coeffs[i]) > 1e-5 ])
+            all_formulas1 = set([rxn1.all_comp[i].reduced_formula
+                                 for i in xrange(len(rxn1.all_comp))
+                                 if abs(rxn1.coeffs[i]) > 1e-5])
             for pair2 in self:
                 rxn2 = pair2.rxn
-                all_formulas2 = set([rxn2.all_comp[i].reduced_formula for i in xrange(len(rxn2.all_comp)) if abs(rxn2.coeffs[i]) > 1e-5 ])
+                all_formulas2 = set([rxn2.all_comp[i].reduced_formula
+                                     for i in xrange(len(rxn2.all_comp))
+                                     if abs(rxn2.coeffs[i]) > 1e-5])
                 if all_formulas1 == all_formulas2:
                     found = True
                     break
@@ -191,10 +209,14 @@ class ConversionElectrode(AbstractElectrode):
         for pair1 in conversion_electrode:
             found = False
             rxn1 = pair1.rxn
-            all_formulas1 = set([rxn1.all_comp[i].reduced_formula for i in xrange(len(rxn1.all_comp)) if abs(rxn1.coeffs[i]) > 1e-5 ])
+            all_formulas1 = set([rxn1.all_comp[i].reduced_formula
+                                 for i in xrange(len(rxn1.all_comp))
+                                 if abs(rxn1.coeffs[i]) > 1e-5])
             for pair2 in self:
                 rxn2 = pair2.rxn
-                all_formulas2 = set([rxn2.all_comp[i].reduced_formula for i in xrange(len(rxn2.all_comp)) if abs(rxn2.coeffs[i]) > 1e-5 ])
+                all_formulas2 = set([rxn2.all_comp[i].reduced_formula
+                                     for i in xrange(len(rxn2.all_comp))
+                                     if abs(rxn2.coeffs[i]) > 1e-5])
                 if all_formulas1 == all_formulas2:
                     found = True
                     break
@@ -209,10 +231,17 @@ class ConversionElectrode(AbstractElectrode):
         return self.__repr__()
 
     def __repr__(self):
-        output = ['Conversion electrode with formula {} and nsteps {}'.format(self._composition.reduced_formula, self.num_steps)]
-        output.append('Average voltage {} V, min voltage {} V, max voltage {} V'.format(self.get_average_voltage(), self.min_voltage, self.max_voltage))
-        output.append('Capacity (grav.) {} mAh/g, capacity (vol.) {} Ah/l'.format(self.get_capacity_grav(), self.get_capacity_vol()))
-        output.append('Specific energy {} Wh/kg, energy density {} Wh/l'.format(self.get_specific_energy(), self.get_energy_density()))
+        output = ['Conversion electrode with formula {} and nsteps {}'
+                  .format(self._composition.reduced_formula, self.num_steps)]
+        output.append('Avg voltage {} V, min voltage {} V, max voltage {} V'
+                      .format(self.get_average_voltage(), self.min_voltage,
+                              self.max_voltage))
+        output.append('Capacity (grav.) {} mAh/g, capacity (vol.) {} Ah/l'
+                      .format(self.get_capacity_grav(),
+                              self.get_capacity_vol()))
+        output.append('Specific energy {} Wh/kg, energy density {} Wh/l'
+                      .format(self.get_specific_energy(),
+                              self.get_energy_density()))
         return "\n".join(output)
 
     @staticmethod
@@ -238,13 +267,15 @@ class ConversionElectrode(AbstractElectrode):
         Arguments:
             print_subelectrodes:
                 Also print data on all the possible subelectrodes
-        
+
         Returns:
             a summary of this electrode's properties in dictionary format
         '''
 
         d = {}
-        framework_comp = Composition({k: v for k, v in self._composition.items() if k.symbol != self.working_ion.symbol })
+        framework_comp = Composition({k: v
+                                      for k, v in self._composition.items()
+                                      if k.symbol != self.working_ion.symbol})
 
         d['framework'] = framework_comp.to_data_dict
         d['framework_pretty'] = framework_comp.reduced_formula
@@ -272,15 +303,20 @@ class ConversionElectrode(AbstractElectrode):
             for i in xrange(len(rxn.coeffs)):
                 if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i] not in comps:
                     comps.append(rxn.all_comp[i])
-                if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i].reduced_formula != d['working_ion']:
-                    d['reactant_compositions'].append(rxn.all_comp[i].get_reduced_composition_and_factor()[0].to_dict)
+                if abs(rxn.coeffs[i]) > 1e-5 and \
+                    rxn.all_comp[i].reduced_formula != d['working_ion']:
+                    reduced_comp = rxn.all_comp[i].reduced_composition
+                    comp_dict = reduced_comp.to_dict
+                    d['reactant_compositions'].append(comp_dict)
         d['fracA_charge'] = min(frac)
         d['fracA_discharge'] = max(frac)
         d['nsteps'] = self.num_steps
         if print_subelectrodes:
             f_dict = lambda c: c.get_summary_dict(print_subelectrodes=False)
-            d['adj_pairs'] = map(f_dict, self.get_sub_electrodes(adjacent_only=True))
-            d['all_pairs'] = map(f_dict, self.get_sub_electrodes(adjacent_only=False))
+            d['adj_pairs'] = map(f_dict,
+                                 self.get_sub_electrodes(adjacent_only=True))
+            d['all_pairs'] = map(f_dict,
+                                 self.get_sub_electrodes(adjacent_only=False))
         return d
 
 
@@ -341,7 +377,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
         """
         Creates a ConversionVoltagePair from two steps in the element profile
         from a PD analysis.
-        
+
         Args:
             step1:
                 Starting step
@@ -354,12 +390,15 @@ class ConversionVoltagePair(AbstractVoltagePair):
         working_ion_entry = step1['element_reference']
         working_ion = working_ion_entry.composition.elements[0].symbol
         voltage = -step1['chempot'] + working_ion_entry.energy_per_atom
-        mAh = (step2['evolution'] - step1['evolution']) * ELECTRON_TO_AMPERE_HOURS * 1000
+        mAh = (step2['evolution'] - step1['evolution']) \
+            * ELECTRON_TO_AMPERE_HOURS * 1000
         licomp = Composition.from_formula(working_ion)
         prev_rxn = step1['reaction']
-        reactants = {comp:abs(prev_rxn.get_coeff(comp)) for comp in prev_rxn.products if comp != licomp}
+        reactants = {comp: abs(prev_rxn.get_coeff(comp))
+                     for comp in prev_rxn.products if comp != licomp}
         curr_rxn = step2['reaction']
-        products = {comp:abs(curr_rxn.get_coeff(comp)) for comp in curr_rxn.products if comp != licomp}
+        products = {comp: abs(curr_rxn.get_coeff(comp))
+                    for comp in curr_rxn.products if comp != licomp}
         reactants[licomp] = (step2['evolution'] - step1['evolution'])
 
         rxn = BalancedReaction(reactants, products)
@@ -369,12 +408,22 @@ class ConversionVoltagePair(AbstractVoltagePair):
                 rxn.normalize_to_element(el, amt)
                 break
 
-        prev_mass_discharge = sum([prev_rxn.all_comp[i].weight * abs(prev_rxn.coeffs[i]) for i in xrange(len(prev_rxn.all_comp))]) / 2
-        vol_charge = sum([abs(prev_rxn.get_coeff(e.composition)) * e.structure.volume for e in step1['entries'] if e.composition.reduced_formula != working_ion])
-        mass_discharge = sum([curr_rxn.all_comp[i].weight * abs(curr_rxn.coeffs[i]) for i in xrange(len(curr_rxn.all_comp))]) / 2
-        mass_charge = prev_mass_discharge
+        prev_mass_dischg = sum([prev_rxn.all_comp[i].weight
+                                * abs(prev_rxn.coeffs[i])
+                                for i in xrange(len(prev_rxn.all_comp))]) / 2
+        vol_charge = sum([abs(prev_rxn.get_coeff(e.composition))
+                          * e.structure.volume
+                          for e in step1['entries']
+                          if e.composition.reduced_formula != working_ion])
+        mass_discharge = sum([curr_rxn.all_comp[i].weight
+                              * abs(curr_rxn.coeffs[i])
+                              for i in xrange(len(curr_rxn.all_comp))]) / 2
+        mass_charge = prev_mass_dischg
         mass_discharge = mass_discharge
-        vol_discharge = sum([abs(curr_rxn.get_coeff(e.composition)) * e.structure.volume for e in step2['entries'] if e.composition.reduced_formula != working_ion])
+        vol_discharge = sum([abs(curr_rxn.get_coeff(e.composition))
+                             * e.structure.volume
+                             for e in step2['entries']
+                             if e.composition.reduced_formula != working_ion])
 
         totalcomp = Composition({})
         for comp in prev_rxn.products:
@@ -393,7 +442,8 @@ class ConversionVoltagePair(AbstractVoltagePair):
         entries_discharge = step1['entries']
 
         return ConversionVoltagePair(rxn, voltage, mAh, vol_charge,
-                                     vol_discharge, mass_charge, mass_discharge,
+                                     vol_discharge, mass_charge,
+                                     mass_discharge,
                                      frac_charge, frac_discharge,
                                      entries_charge, entries_discharge,
                                      working_ion_entry)
@@ -451,12 +501,16 @@ class ConversionVoltagePair(AbstractVoltagePair):
         return self._working_ion_entry
 
     def __repr__(self):
-        output = ["Conversion voltage pair with working ion {}".format(self._working_ion_entry.composition.reduced_formula)]
+        output = ["Conversion voltage pair with working ion {}"
+                  .format(self._working_ion_entry.composition.reduced_formula)]
         output.append("Reaction : {}".format(self._rxn))
         output.append("V = {}, mAh = {}".format(self.voltage, self.mAh))
-        output.append("frac_charge = {}, frac_discharge = {}".format(self.frac_charge, self.frac_discharge))
-        output.append("mass_charge = {}, mass_discharge = {}".format(self.mass_charge, self.mass_discharge))
-        output.append("vol_charge = {}, vol_discharge = {}".format(self.vol_charge, self.vol_discharge))
+        output.append("frac_charge = {}, frac_discharge = {}"
+                      .format(self.frac_charge, self.frac_discharge))
+        output.append("mass_charge = {}, mass_discharge = {}"
+                      .format(self.mass_charge, self.mass_discharge))
+        output.append("vol_charge = {}, vol_discharge = {}"
+                      .format(self.vol_charge, self.vol_discharge))
         return "\n".join(output)
 
     def __str__(self):
@@ -473,7 +527,8 @@ class ConversionVoltagePair(AbstractVoltagePair):
                                    d['vol_charge'], d['vol_discharge'],
                                    d['mass_charge'], d['mass_discharge'],
                                    d['frac_charge'], d['frac_discharge'],
-                                   entries_charge, entries_discharge, working_ion_entry)
+                                   entries_charge, entries_discharge,
+                                   working_ion_entry)
 
     @property
     def to_dict(self):
@@ -493,4 +548,3 @@ class ConversionVoltagePair(AbstractVoltagePair):
         d['entries_charge'] = [e.to_dict for e in self._entries_charge]
         d['entries_discharge'] = [e.to_dict for e in self._entries_discharge]
         return d
-
