@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
-'''
-This module implements an interface to enumlib, Gus Hart's excellent Fortran
+"""
+This module implements an interface to enumlib, Gus Hart"s excellent Fortran
 code for enumerating derivative structures.
 
 This module depends on a compiled enumlib with the executables multienum.x and
-makestr.x available in the path. Please download the library at 
-http://enum.sourceforge.net/ and follow the instructions in the README to 
+makestr.x available in the path. Please download the library at
+http://enum.sourceforge.net/ and follow the instructions in the README to
 compile these two executables accordingly.
 
 If you use this module, please cite the following:
@@ -15,12 +15,12 @@ Gus L. W. Hart and Rodney W. Forcade, "Algorithm for generating derivative
 structures," Phys. Rev. B 77 224115 (26 June 2008)
 
 Gus L. W. Hart and Rodney W. Forcade, "Generating derivative structures from
-multilattices: Application to hcp alloys," Phys. Rev. B 80 014120 (July 2009) 
+multilattices: Application to hcp alloys," Phys. Rev. B 80 014120 (July 2009)
 
 Gus L. W. Hart, Lance J. Nelson, and Rodney W. Forcade, "Generating
 derivative structures at a fixed concentration," Comp. Mat. Sci. 59
 101-107 (March 2012)
-'''
+"""
 
 from __future__ import division
 
@@ -45,7 +45,7 @@ import warnings
 from pymatgen.io.vaspio.vasp_input import Poscar
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
-from pymatgen.symmetry.spglib_adaptor import SymmetryFinder
+from pymatgen.symmetry.finder import SymmetryFinder
 from pymatgen.core.structure_modifier import SupercellMaker
 from pymatgen.core.periodic_table import DummySpecie
 
@@ -56,15 +56,16 @@ logger = logging.getLogger(__name__)
 class EnumlibAdaptor(object):
     """
     An adaptor for enumlib.
-    
+
     .. attribute:: structures
-    
+
         List of all enumerated structures.
     """
     amount_tol = 1e-5
 
     def __init__(self, structure, min_cell_size=1, max_cell_size=1,
-                 symm_prec=0.1):
+                 symm_prec=0.1, enum_precision_parameter=0.001,
+                 refine_structure=False):
         """
         Args:
             structure:
@@ -75,11 +76,29 @@ class EnumlibAdaptor(object):
                 The maximum cell size wanted. Must be an int. Defaults to 1.
             symm_prec:
                 Symmetry precision. Defaults to 0.1.
+            enum_precision_parameter:
+                Finite precision parameter for enumlib. Default of 0.001 is
+                usually ok, but you might need to tweak it for certain cells.
+            refine_structure:
+                If you are starting from a structure that has been relaxed via
+                some electronic structure code, it is usually much better to
+                start with symmetry determination and then obtain a refined
+                structure. The refined structure have cell parameters and
+                atomic positions shifted to the expected symmetry positions,
+                which makes it much less sensitive precision issues in enumlib.
+                If you are already starting from an experimental cif, refinment
+                should have already been done and it is not necessary. Defaults
+                to False.
         """
-        self.structure = structure
+        if refine_structure:
+            finder = SymmetryFinder(structure, symm_prec)
+            self.structure = finder.get_refined_structure()
+        else:
+            self.structure = structure
         self.min_cell_size = min_cell_size
         self.max_cell_size = max_cell_size
         self.symm_prec = symm_prec
+        self.enum_precision_parameter = enum_precision_parameter
 
     def run(self):
         """
@@ -99,8 +118,9 @@ class EnumlibAdaptor(object):
                 self.structures = self._get_structures(temp_dir, num_structs)
             else:
                 raise ValueError("Unable to enumerate structure.")
-        except Exception as ex:
-            import sys, traceback
+        except Exception:
+            import sys
+            import traceback
             exc_type, exc_value, exc_traceback = sys.exc_info()
             traceback.print_exception(exc_type, exc_value, exc_traceback,
                               limit=2, file=sys.stdout)
@@ -122,11 +142,13 @@ class EnumlibAdaptor(object):
         # Using symmetry finder, get the symmetrically distinct sites.
         fitter = SymmetryFinder(self.structure, self.symm_prec)
         symmetrized_structure = fitter.get_symmetrized_structure()
-        logger.debug("Spacegroup {} ({}) with {} distinct sites".format(fitter.get_spacegroup_symbol(),
-                     fitter.get_spacegroup_number(), len(symmetrized_structure.equivalent_sites)))
+        logger.debug("Spacegroup {} ({}) with {} distinct sites"
+                     .format(fitter.get_spacegroup_symbol(),
+                             fitter.get_spacegroup_number(),
+                             len(symmetrized_structure.equivalent_sites)))
 
         """
-        Enumlib doesn't work when the number of species get too large. To
+        Enumlib doesn"t work when the number of species get too large. To
         simplify matters, we generate the input file only with disordered sites
         and exclude the ordered sites from the enumeration. The fact that
         different disordered sites with the exact same species may belong to
@@ -139,24 +161,42 @@ class EnumlibAdaptor(object):
         index_species = []
         index_amounts = []
 
+        #Let"s group and sort the sites by symmetry.
+        site_symmetries = []
+        for sites in symmetrized_structure.equivalent_sites:
+            finder = SymmetryFinder(Structure.from_sites(sites),
+                                    self.symm_prec)
+            sgnum = finder.get_spacegroup_number()
+            site_symmetries.append((sites, sgnum))
+
+        site_symmetries = sorted(site_symmetries, key=lambda s: s[1])
+
         #Stores the ordered sites, which are not enumerated.
+        min_sg_num = site_symmetries[0][1]
         ordered_sites = []
         disordered_sites = []
         coord_str = []
-        for sites in symmetrized_structure.equivalent_sites:
+        min_disordered_sg = 300
+        for (sites, sgnum) in site_symmetries:
             if sites[0].is_ordered:
-                ordered_sites.extend(sites)
+                ordered_sites.append(sites)
             else:
+                min_disordered_sg = min(min_disordered_sg, sgnum)
                 sp_label = []
                 species = sites[0].species_and_occu
                 if sum(species.values()) < 1 - EnumlibAdaptor.amount_tol:
                     #Let us first make add a dummy element for every single
-                    #site whose total occupancies don't sum to 1.
+                    #site whose total occupancies don"t sum to 1.
                     species[DummySpecie("X")] = 1 - sum(species.values())
                 for sp in species.keys():
-                    index_species.append(sp)
-                    sp_label.append(len(index_species) - 1)
-                    index_amounts.append(species[sp] * len(sites))
+                    if sp not in index_species:
+                        index_species.append(sp)
+                        sp_label.append(len(index_species) - 1)
+                        index_amounts.append(species[sp] * len(sites))
+                    else:
+                        ind = index_species.index(sp)
+                        sp_label.append(ind)
+                        index_amounts[ind] += species[sp] * len(sites)
                 sp_label = "/".join(["{}".format(i) for i in sorted(sp_label)])
                 for site in sites:
                     coord_str.append("{} {}".format(
@@ -164,13 +204,32 @@ class EnumlibAdaptor(object):
                                         sp_label))
                 disordered_sites.append(sites)
 
-        self.ordered_sites = ordered_sites
+        #It could be that some of the ordered sites has a lower symmetry than
+        #the disordered sites.  So we consider the lowest symmetry sites as
+        #disordered in our enumeration.
+        if min_disordered_sg > min_sg_num:
+            logger.debug("Ordered sites have lower symmetry than disordered.")
+            sites = ordered_sites.pop(0)
+            index_species.append(sites[0].specie)
+            index_amounts.append(len(sites))
+            sp_label = len(index_species) - 1
+            logger.debug("Lowest symmetry {} sites are included in enum."
+                         .format(sites[0].specie))
+            for site in sites:
+                coord_str.append("{} {}".format(
+                                        coord_format.format(*site.coords),
+                                        sp_label))
+            disordered_sites.append(sites)
+
+        self.ordered_sites = []
+        for sites in ordered_sites:
+            self.ordered_sites.extend(sites)
         self.index_species = index_species
 
         lattice = self.structure.lattice
 
         output = [self.structure.formula]
-        output.append('bulk')
+        output.append("bulk")
         for vec in lattice.matrix:
             output.append(coord_format.format(*vec))
         output.append("{}".format(len(index_species)))
@@ -178,7 +237,7 @@ class EnumlibAdaptor(object):
         output.extend(coord_str)
 
         output.append("{} {}".format(self.min_cell_size, self.max_cell_size))
-        output.append(str(self.symm_prec))
+        output.append(str(self.enum_precision_parameter))
         output.append("partial")
         #To get a reasonable number of structures, we fix concentrations to the
         #range expected in the original structure.
@@ -190,7 +249,8 @@ class EnumlibAdaptor(object):
                                                 int(round(conc * 100)), 100))
             else:
                 min_conc = int(math.floor(conc * 100))
-                output.append("{} {} {}".format(min_conc - 1, min_conc + 1, 100))
+                output.append("{} {} {}".format(min_conc - 1, min_conc + 1,
+                                                100))
         output.append("")
         logger.debug("Generated input file:\n{}".format("\n".join(output)))
         with open(os.path.join(working_dir, "struct_enum.in"), "w") as f:
@@ -198,7 +258,7 @@ class EnumlibAdaptor(object):
 
     def _run_multienum(self, working_dir):
         os.chdir(working_dir)
-        p = subprocess.Popen(['multienum.x'],
+        p = subprocess.Popen(["multienum.x"],
                              stdout=subprocess.PIPE,
                              stdin=subprocess.PIPE, close_fds=True)
         output = p.communicate()[0]
@@ -214,17 +274,19 @@ class EnumlibAdaptor(object):
 
     def _get_structures(self, working_dir, num_structs):
         structs = []
-        rs = subprocess.Popen(['makestr.x',
-                               'struct_enum.out', str(0), str(num_structs - 1)],
+        rs = subprocess.Popen(["makestr.x",
+                               "struct_enum.out", str(0),
+                               str(num_structs - 1)],
                               stdout=subprocess.PIPE,
                               stdin=subprocess.PIPE, close_fds=True)
         rs.communicate()
         if len(self.ordered_sites) > 0:
             original_latt = self.ordered_sites[0].lattice
             ordered_structure = Structure.from_sites(self.ordered_sites)
+            inv_org_latt = np.linalg.inv(original_latt.matrix)
 
         for n in range(1, num_structs + 1):
-            with open('vasp.{:06d}'.format(n)) as f:
+            with open("vasp.{:06d}".format(n)) as f:
                 data = f.read()
                 data = re.sub("scale factor", "1", data)
                 data = re.sub("(\d+)-(\d+)", r"\1 -\2", data)
@@ -238,8 +300,7 @@ class EnumlibAdaptor(object):
                 sites = []
 
                 if len(self.ordered_sites) > 0:
-                    transformation = np.dot(new_latt.matrix,
-                                            np.linalg.inv(original_latt.matrix))
+                    transformation = np.dot(new_latt.matrix, inv_org_latt)
                     transformation = [[int(round(cell)) for cell in row] \
                                       for row in transformation]
                     logger.debug("Supercell matrix: {}".format(transformation))
@@ -251,7 +312,7 @@ class EnumlibAdaptor(object):
                     super_latt = new_latt
 
                 for site in sub_structure:
-                    if site.specie.symbol != "X": #We exclude vacancies.
+                    if site.specie.symbol != "X":  # We exclude vacancies.
                         sites.append(PeriodicSite(site.species_and_occu,
                                                   site.frac_coords,
                                                   super_latt).to_unit_cell)
@@ -259,5 +320,3 @@ class EnumlibAdaptor(object):
 
         logger.debug("Read in a total of {} structures.".format(num_structs))
         return structs
-
-
