@@ -25,17 +25,17 @@ class Dos(MSONable):
     """
     Basic DOS object. All other DOS objects are extended versions of this
     object.
-    
+
     .. attribute: energies
-    
+
         The sequence of energies
-        
+
     .. attribute: densities
-    
+
         A dict of spin densities, e.g., {Spin.up: [...], Spin.down: [...]}
-        
+
     .. attribute: efermi
-    
+
         Fermi level
     """
 
@@ -47,21 +47,21 @@ class Dos(MSONable):
             energies:
                 A sequences of energies
             densities:
-                A dict of {Spin: np.array} representing the density of states 
+                A dict of {Spin: np.array} representing the density of states
                 for each Spin.
         """
         self.efermi = efermi
         self.energies = np.array(energies)
-        self.densities = {k:np.array(d) for k, d in densities.items()}
+        self.densities = {k: np.array(d) for k, d in densities.items()}
 
     def get_densities(self, spin=None):
         """
         Returns the density of states for a particular spin.
-        
+
         Args:
             spin:
                 Spin
-                
+
         Returns:
             Returns the density of states for a particular spin. If Spin is
             None, the sum of all spins is returned.
@@ -79,20 +79,21 @@ class Dos(MSONable):
 
     def get_smeared_densities(self, sigma):
         """
-        Returns the Dict representation of the densities, {Spin: densities}, 
+        Returns the Dict representation of the densities, {Spin: densities},
         but with a Gaussian smearing of std dev sigma applied about the fermi
         level.
-        
+
         Args:
             sigma:
                 Std dev of Gaussian smearing function.
-                
+
         Returns:
             Dict of Gaussian-smeared densities.
         """
         from scipy.ndimage.filters import gaussian_filter1d
         smeared_dens = {}
-        diff = [self.energies[i + 1] - self.energies[i] for i in xrange(len(self.energies) - 1)]
+        diff = [self.energies[i + 1] - self.energies[i]
+                for i in xrange(len(self.energies) - 1)]
         avgdiff = sum(diff) / len(diff)
         for spin, dens in self.densities.items():
             smeared_dens[spin] = gaussian_filter1d(dens, sigma / avgdiff)
@@ -100,25 +101,26 @@ class Dos(MSONable):
 
     def __add__(self, other):
         """
-        Adds two DOS together. Checks that energy scales are the same. 
+        Adds two DOS together. Checks that energy scales are the same.
         Otherwise, a ValueError is thrown.
-        
+
         Args:
             other:
                 Another DOS object.
-                
+
         Returns:
             Sum of the two DOSs.
         """
         if not (self.energies == other.energies).all():
             raise ValueError("Energies of both DOS are not compatible!")
-        densities = {spin: self.densities[spin] + other.densities[spin] for spin in self.densities.keys()}
+        densities = {spin: self.densities[spin] + other.densities[spin]
+                     for spin in self.densities.keys()}
         return Dos(self.efermi, self.energies, densities)
 
     def get_interpolated_value(self, energy):
         """
         Returns interpolated density for a particular energy.
-        
+
         Args:
             energy:
                 Energy to return the density for.
@@ -126,13 +128,14 @@ class Dos(MSONable):
         f = {}
         for spin in self.densities.keys():
             f[spin] = get_linear_interpolated_value(self.energies,
-                                                    self.densities[spin], energy)
+                                                    self.densities[spin],
+                                                    energy)
         return f
 
     def get_interpolated_gap(self, tol=0.001, abs_tol=False, spin=None):
         """
         Expects a DOS object and finds the gap
-        
+
         Args:
             tol:
                 tolerance in occupations for determining the gap
@@ -144,7 +147,7 @@ class Dos(MSONable):
                     None - finds the ap in the summed densities
                     Up - finds the gap in the up spin channel
                     Down - finds the gap in teh down spin channel
-        
+
         Returns:
             (gap, cbm, vbm):
                 Tuple of floats in eV corresponding to the gap, cbm and vbm.
@@ -154,33 +157,41 @@ class Dos(MSONable):
         if abs_tol == False:
             tol = tol * tdos.sum() / tdos.shape[0]
         energies = self.energies
-        below_fermi = [i for i in xrange(len(energies)) if energies[i] < self.efermi and tdos[i] > tol]
-        above_fermi = [i for i in xrange(len(energies)) if energies[i] > self.efermi and tdos[i] > tol]
+        below_fermi = [i for i in xrange(len(energies))
+                       if energies[i] < self.efermi and tdos[i] > tol]
+        above_fermi = [i for i in xrange(len(energies))
+                       if energies[i] > self.efermi and tdos[i] > tol]
         vbm_start = max(below_fermi)
         cbm_start = min(above_fermi)
         if vbm_start == cbm_start:
             return 0.0, self.efermi, self.efermi
         else:
             # Interpolate between adjacent values
-            start = get_linear_interpolated_value(tdos[vbm_start:vbm_start + 2][::-1], energies[vbm_start:vbm_start + 2][::-1], tol)
-            end = get_linear_interpolated_value(tdos[cbm_start - 1:cbm_start + 1], energies[cbm_start - 1:cbm_start + 1], tol)
+            terminal_dens = tdos[vbm_start:vbm_start + 2][::-1]
+            terminal_energies = energies[vbm_start:vbm_start + 2][::-1]
+            start = get_linear_interpolated_value(terminal_dens,
+                                                  terminal_energies, tol)
+            terminal_dens = tdos[cbm_start - 1:cbm_start + 1]
+            terminal_energies = energies[cbm_start - 1:cbm_start + 1]
+            end = get_linear_interpolated_value(terminal_dens,
+                                                terminal_energies, tol)
             return end - start, end, start
 
     def get_cbm_vbm(self, tol=0.001, abs_tol=False, spin=None):
         """
         Expects a DOS object and finds the cbm and vbm.
-        
+
         Args:
-            tol: 
+            tol:
                 tolerance in occupations for determining the gap
-            abs_tol: 
+            abs_tol:
                 an absolute tolerance (True) and a relative one (False)
             spin:
                 Possible values are:
                     None - finds the gap in the summed densities
                     Up - finds the gap in the up spin channel
                     Down - finds the gap in teh down spin channel
-        
+
         Returns:
             (cbm, vbm): float in eV corresponding to the gap
         """
@@ -196,12 +207,12 @@ class Dos(MSONable):
 
         # work backwards until tolerance is reached
         i_gap_start = i_fermi
-        while i_gap_start - 1 >= 0 and tdos[i_gap_start - 1] <= tol :
+        while i_gap_start - 1 >= 0 and tdos[i_gap_start - 1] <= tol:
             i_gap_start -= 1
 
         # work forwards until tolerance is reached
         i_gap_end = i_gap_start
-        while i_gap_end < tdos.shape[0] and tdos[i_gap_end] <= tol :
+        while i_gap_end < tdos.shape[0] and tdos[i_gap_end] <= tol:
             i_gap_end += 1
         i_gap_end -= 1
         return (self.energies[i_gap_end], self.energies[i_gap_start])
@@ -209,18 +220,18 @@ class Dos(MSONable):
     def get_gap(self, tol=0.001, abs_tol=False, spin=None):
         """
         Expects a DOS object and finds the gap.
-        
+
         Args:
-            tol: 
+            tol:
                 tolerance in occupations for determining the gap
-            abs_tol: 
+            abs_tol:
                 an absolute tolerance (True) and a relative one (False)
             spin:
                 Possible values are:
                     None - finds the gap in the summed densities
                     Up - finds the gap in the up spin channel
                     Down - finds the gap in teh down spin channel
-        
+
         Returns:
             gap in eV
         """
@@ -232,11 +243,18 @@ class Dos(MSONable):
         Returns a string which can be easily plotted (using gnuplot).
         """
         if Spin.down in self.densities:
-            stringarray = ["#%30s %30s %30s" % ('Energy', 'DensityUp', 'DensityDown')]
-            stringarray.extend(["%.5f %.5f %.5f" % (self.energies[i], self.densities[Spin.up][i], self.densities[Spin.down][i]) for i in range(len(self.energies))])
+            stringarray = ["#{:30s} {:30s} {:30s}".format('Energy',
+                                                          'DensityUp',
+                                                          'DensityDown')]
+            for i, energy in enumerate(self.energies):
+                stringarray.append("{:.5f} {:.5f} {:.5f}".
+                                    format(energy, self.densities[Spin.up][i],
+                                           self.densities[Spin.down][i]))
         else:
-            stringarray = ["#%30s %30s" % ('Energy', 'DensityUp')]
-            stringarray.extend(["%.5f %.5f" % (self.energies[i], self.densities[Spin.up][i]) for i in range(len(self.energies))])
+            stringarray = ["#{:30s} {:30s}".format('Energy', 'DensityUp')]
+            for i, energy in enumerate(self.energies):
+                stringarray.append("{:.5f} {:.5f}"
+                                   .format(energy, self.densities[Spin.up][i]))
         return "\n".join(stringarray)
 
     @staticmethod
@@ -244,7 +262,9 @@ class Dos(MSONable):
         """
         Returns Dos object from dict representation of Dos.
         """
-        return Dos(d['efermi'], d['energies'], {Spin.from_int(int(k)):v for k, v in d['densities'].items()})
+        return Dos(d['efermi'], d['energies'],
+                   {Spin.from_int(int(k)): v
+                    for k, v in d['densities'].items()})
 
     @property
     def to_dict(self):
@@ -256,7 +276,8 @@ class Dos(MSONable):
         d['class'] = self.__class__.__name__
         d['efermi'] = self.efermi
         d['energies'] = list(self.energies)
-        d['densities'] = { str(int(spin)) : list(dens) for spin , dens in self.densities.items() }
+        d['densities'] = {str(int(spin)): list(dens)
+                          for spin, dens in self.densities.items() }
         return d
 
 
@@ -266,13 +287,13 @@ class CompleteDos(Dos):
     Mainly used by pymatgen.io.vaspio.Vasprun to create a complete Dos from
     a vasprun.xml file. You are unlikely to try to generate this object
     manually.
-    
+
     .. attribute:: structure
 
         Structure associated with the CompleteDos.
-    
+
     .. attribute:: pdos
-        
+
         Dict of partial densities of the form {Site:{Orbital:{Spin:Densities}}}
     """
 
@@ -295,13 +316,13 @@ class CompleteDos(Dos):
     def get_site_orbital_dos(self, site, orbital):
         """
         Get the Dos for a particular orbital of a particular site.
-        
+
         Args:
             site:
                 Site in Structure associated with CompleteDos.
             orbital:
                 Orbital in the site.
-                
+
         Returns:
             Dos containing densities for orbital of site.
         """
@@ -310,11 +331,11 @@ class CompleteDos(Dos):
     def get_site_dos(self, site):
         """
         Get the total Dos for a site (all orbitals).
-        
+
         Args:
             site:
                 Site in Structure associated with CompleteDos.
-                
+
         Returns:
             Dos containing summed orbital densities for site.
         """
@@ -337,13 +358,15 @@ class CompleteDos(Dos):
                     elif orb in (Orbital.dx2, Orbital.dz2):
                         eg_dos.append(pdos)
         sum_dos = lambda a, b: add_densities(a, b)
-        return {'t2g':Dos(self.efermi, self.energies, reduce(sum_dos, t2g_dos)),
-                'e_g':Dos(self.efermi, self.energies, reduce(sum_dos, eg_dos))}
+        return {'t2g': Dos(self.efermi, self.energies,
+                           reduce(sum_dos, t2g_dos)),
+                'e_g': Dos(self.efermi, self.energies,
+                           reduce(sum_dos, eg_dos))}
 
     def get_spd_dos(self):
         """
         Get orbital projected Dos.
-        
+
         Returns:
             dict of {orbital: Dos}, e.g. {'s': Dos object, ...}
         """
@@ -355,12 +378,13 @@ class CompleteDos(Dos):
                     spd_dos[orbital_type] = pdos
                 else:
                     spd_dos[orbital_type] = add_densities(spd_dos[orbital_type], pdos)
-        return {orb:Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
+        return {orb: Dos(self.efermi, self.energies, densities)
+                for orb, densities in spd_dos.items()}
 
     def get_element_dos(self):
         """
         Get element projected Dos.
-        
+
         Returns:
             dict of {Element: Dos}
         """
@@ -373,8 +397,8 @@ class CompleteDos(Dos):
                     el_dos[el] = pdos
                 else:
                     el_dos[el] = add_densities(el_dos[el], pdos)
-        return {el:Dos(self.efermi, self.energies, densities) for el,
-                densities in el_dos.items()}
+        return {el: Dos(self.efermi, self.energies, densities)
+                for el, densities in el_dos.items()}
 
     @staticmethod
     def from_dict(d):
@@ -389,8 +413,8 @@ class CompleteDos(Dos):
             orb_dos = {}
             for orb_str, odos in d['pdos'][i].items():
                 orb = Orbital.from_string(orb_str)
-                orb_dos[orb] = {Spin.from_int(int(k)):v for k,
-                                v in odos['densities'].items()}
+                orb_dos[orb] = {Spin.from_int(int(k)): v
+                                for k, v in odos['densities'].items()}
             pdoss[at] = orb_dos
         return CompleteDos(struct, tdos, pdoss)
 
@@ -405,15 +429,16 @@ class CompleteDos(Dos):
         d['efermi'] = self.efermi
         d['structure'] = self.structure.to_dict
         d['energies'] = list(self.energies)
-        d['densities'] = {str(int(spin)) : list(dens) for spin,
-                          dens in self.densities.items()}
+        d['densities'] = {str(int(spin)): list(dens)
+                          for spin, dens in self.densities.items()}
         d['pdos'] = []
         if len(self.pdos) > 0:
             for at in self.structure:
                 dd = {}
                 for orb, pdos in self.pdos[at].items():
-                    dd[str(orb)] = {'densities' : {str(int(spin)): list(dens) for spin,
-                                                            dens in pdos.items() }}
+                    dd[str(orb)] = {'densities': {str(int(spin)): list(dens)
+                                                  for spin,
+                                                  dens in pdos.items()}}
                 d['pdos'].append(dd)
             d['atom_dos'] = {str(at): dos.to_dict for at,
                              dos in self.get_element_dos().items()}
@@ -426,4 +451,5 @@ class CompleteDos(Dos):
 
 
 def add_densities(density1, density2):
-    return {spin: np.array(density1[spin]) + np.array(density2[spin]) for spin in density1.keys()}
+    return {spin: np.array(density1[spin]) + np.array(density2[spin])
+            for spin in density1.keys()}
