@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 '''
-Created on Mar 19, 2012
+This module implements Compatibility corrections for mixing runs of different
+functionals.
 '''
 
 from __future__ import division
@@ -34,16 +35,16 @@ class Compatibility(EntryPostProcessor):
         """
         Args:
             input_set_name:
-                The name of the input set to use. Can be either MaterialsProject
-                or MITMatgen.
+                The name of the input set to use. Can be either
+                MaterialsProject or MITMatgen.
             compat_type:
-                Two options, GGA or Advanced.  GGA means all GGA+U entries are 
-                excluded.  Advanced means mixing scheme is implemented to make 
-                entries compatible with each other, but entries which are 
-                supposed to be done in GGA+U will have the equivalent GGA entries 
-                excluded. For example, Fe oxides should have a U value under the 
-                Advanced scheme. A GGA Fe oxide run will therefore be excluded 
-                under the scheme.
+                Two options, GGA or Advanced.  GGA means all GGA+U entries are
+                excluded.  Advanced means mixing scheme is implemented to make
+                entries compatible with each other, but entries which are
+                supposed to be done in GGA+U will have the equivalent GGA
+                entries excluded. For example, Fe oxides should have a U value
+                under the Advanced scheme. A GGA Fe oxide run will therefore be
+                excluded under the scheme.
         """
         self.compat_type = compat_type
         self.input_set_name = input_set_name
@@ -52,7 +53,8 @@ class Compatibility(EntryPostProcessor):
         module_dir = os.path.dirname(os.path.abspath(__file__))
         self._config = ConfigParser.SafeConfigParser()
         self._config.optionxform = str
-        self._config.readfp(open(os.path.join(module_dir, "Compatibility.cfg")))
+        self._config.readfp(open(os.path.join(module_dir,
+                                              "Compatibility.cfg")))
         u_corrections = {}
         for el in self.input_set.incar_settings['LDAUU'].keys():
             name = '{}{}UCorrections{}'.format(input_set_name, compat_type, el)
@@ -60,7 +62,9 @@ class Compatibility(EntryPostProcessor):
                 corr = dict(self._config.items(name))
                 u_corrections[el] = {k: float(v) for k, v in corr.items()}
 
-        cpd_energies = dict(self._config.items('{}{}CompoundEnergies'.format(input_set_name, compat_type)))
+        cpd_energies = dict(self._config.items('{}{}CompoundEnergies'
+                                               .format(input_set_name,
+                                                       compat_type)))
 
         self._u_corrections = u_corrections
         self._cpd_energies = {k: float(v) for k, v in cpd_energies.items()}
@@ -82,17 +86,17 @@ class Compatibility(EntryPostProcessor):
 
         return any([usettings.get(el.symbol, 0) for el in comp.elements])
 
-
     def process_entry(self, entry):
         """
         Process a single entry with the chosen Compatibility scheme.
-        
+
         Args:
             entry:
                 A ComputedEntry object.
-        
+
         Returns:
-            An adjusted entry if entry is compatible, otherwise None is returned.
+            An adjusted entry if entry is compatible, otherwise None is
+            returned.
         """
         if entry.parameters.get('run_type', 'GGA') == "HF":
             return None
@@ -105,14 +109,16 @@ class Compatibility(EntryPostProcessor):
         #Check that POTCARs are valid
         rform = comp.reduced_formula
         if rform not in cpdenergies:
-            psp_settings = set([sym.split(" ")[1] for sym in entry.parameters['potcar_symbols']])
+            psp_settings = set([sym.split(" ")[1]
+                                for sym in entry.parameters['potcar_symbols']])
             if not self._valid_potcars.issuperset(psp_settings):
                 return None
 
         #correct all compounds that are wrong, e.g. O2 molecule
         if rform in cpdenergies:
             entry.structureid = -comp.keys()[0].Z
-            entry.correction = cpdenergies[rform] * comp.num_atoms - entry.uncorrected_energy
+            entry.correction = cpdenergies[rform] * comp.num_atoms \
+                - entry.uncorrected_energy
         else:
             elements = sorted([el for el in comp.elements if comp[el] > 0],
                               key=lambda el: el.X)
@@ -136,12 +142,12 @@ class Compatibility(EntryPostProcessor):
     def process_entries(self, entries):
         """
         Process a sequence of entries with the chosen Compatibility scheme.
-        
+
         Args:
             entries - A sequence of entries.
-        
+
         Returns:
-            An list of adjusted entries.  Entries in the original list which 
+            An list of adjusted entries.  Entries in the original list which
             are not compatible are excluded.
         """
         proc_entries = list()
@@ -156,52 +162,52 @@ class Compatibility(EntryPostProcessor):
         return self._cpd_energies.keys()
 
     def __str__(self):
-        return "{} {} Compatibility".format(self.input_set_name, self.compat_type)
+        return "{} {} Compatibility".format(self.input_set_name,
+                                            self.compat_type)
 
 
 class MaterialsProjectCompatibility(Compatibility):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
-    MaterialsProject parameters (see pymatgen.io.vaspio_set 
+    MaterialsProject parameters (see pymatgen.io.vaspio_set
     MaterialsProjectVaspInputSet). Using this compatibility scheme on runs with
     different parameters is not valid.
     """
 
     def __init__(self, compat_type="Advanced"):
         """
-        Arguments:
+        Args:
             compat_type:
-                Two options, GGA or Advanced.  GGA means all GGA+U entries are 
-                excluded.  Advanced means mixing scheme is implemented to make 
-                entries compatible with each other, but entries which are 
-                supposed to be done in GGA+U will have the equivalent GGA entries 
-                excluded. For example, Fe oxides should have a U value under the 
-                Advanced scheme. A GGA Fe oxide run will therefore be excluded 
-                under the scheme.
+                Two options, GGA or Advanced.  GGA means all GGA+U entries are
+                excluded.  Advanced means mixing scheme is implemented to make
+                entries compatible with each other, but entries which are
+                supposed to be done in GGA+U will have the equivalent GGA
+                entries excluded. For example, Fe oxides should have a U value
+                under the Advanced scheme. A GGA Fe oxide run will therefore be
+                excluded under the scheme.
         """
         Compatibility.__init__(self, "MaterialsProject", compat_type)
 
 
-
 class MITCompatibility(MaterialsProjectCompatibility):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
-    MIT parameters (see pymatgen.io.vaspio_set MITVaspInputSet). Using 
+    MIT parameters (see pymatgen.io.vaspio_set MITVaspInputSet). Using
     this compatibility scheme on runs with different parameters is not valid.
     """
 
     def __init__(self, compat_type="Advanced"):
         """
-        Arguments:
+        Args:
             compat_type:
-                Two options, GGA or Advanced.  GGA means all GGA+U entries are 
-                excluded.  Advanced means mixing scheme is implemented to make 
-                entries compatible with each other, but entries which are 
-                supposed to be done in GGA+U will have the equivalent GGA entries 
-                excluded. For example, Fe oxides should have a U value under the 
-                Advanced scheme. A GGA Fe oxide run will therefore be excluded 
-                under the scheme.
+                Two options, GGA or Advanced.  GGA means all GGA+U entries are
+                excluded.  Advanced means mixing scheme is implemented to make
+                entries compatible with each other, but entries which are
+                supposed to be done in GGA+U will have the equivalent GGA
+                entries excluded. For example, Fe oxides should have a U value
+                under the Advanced scheme. A GGA Fe oxide run will therefore be
+                excluded under the scheme.
         """
         Compatibility.__init__(self, "MITMatgen", compat_type)
