@@ -35,7 +35,8 @@ class GaussianInput(object):
         Args:
             mol:
                 Input molecule. If molecule is a single string, it is used as a
-                direct input to the geometry section of the Gaussian input file.
+                direct input to the geometry section of the Gaussian input
+                file.
             charge:
                 Charge of the molecule. Defaults to 0.
             spin_multiplicity:
@@ -47,11 +48,11 @@ class GaussianInput(object):
             basis_set:
                 Basis set for run.
             route_parameters:
-                Additional route parameters as a dict. For example, 
+                Additional route parameters as a dict. For example,
                 {'SP':"", "SCF":"Tight"}
             input_parameters:
-                Additional input parameters for run as a dict. Used for example,
-                in PCM calculations.  E.g., {"EPS":12}
+                Additional input parameters for run as a dict. Used for
+                example, in PCM calculations.  E.g., {"EPS":12}
         """
         self._mol = mol
         self.charge = charge
@@ -81,9 +82,12 @@ class GaussianInput(object):
             m = var_pattern.match(l.strip())
             if m:
                 paras[m.group(1)] = float(m.group(2))
-        zmat_patt = re.compile("^\s*([A-Za-z]+)[\w\d\-\_]*([\s,]+(\w+)[\s,]+(\w+))*[\-\.\s,\w]*$")
+        zmat_patt = re.compile("^\s*([A-Za-z]+)[\w\d\-\_]*"
+                               "([\s,]+(\w+)[\s,]+(\w+))*[\-\.\s,\w]*$")
         mixed_species_patt = re.compile("([A-Za-z]+)[\d\-\_]+")
-        xyz_patt = re.compile("^\s*([A-Za-z]+[\w\d\-\_]*)\s+([\d\.eE\-]+)\s+([\d\.eE\-]+)\s+([\d\.eE\-]+)[\-\.\s,\w.]*$")
+        xyz_patt = re.compile("^\s*([A-Za-z]+[\w\d\-\_]*)\s+"
+                              "([\d\.eE\-]+)\s+([\d\.eE\-]+)\s+"
+                              "([\d\.eE\-]+)[\-\.\s,\w.]*$")
 
         parsed_species = []
         species = []
@@ -138,7 +142,9 @@ class GaussianInput(object):
                         bl = parameters[0]
                         angle = parameters[1]
                         axis = [0, 1, 0]
-                        coord = SymmOp.from_origin_axis_angle(coords1, axis, angle, False).operate(coords2)
+                        op = SymmOp.from_origin_axis_angle(coords1, axis,
+                                                           angle, False)
+                        coord = op.operate(coords2)
                         vec = coord - coords1
                         coord = vec * bl / np.linalg.norm(vec) + coords1
                         coords.append(coord)
@@ -152,18 +158,24 @@ class GaussianInput(object):
                         v1 = coords3 - coords2
                         v2 = coords1 - coords2
                         axis = np.cross(v1, v2)
-                        coord = SymmOp.from_origin_axis_angle(coords1, axis, angle, False).operate(coords2)
+                        op = SymmOp.from_origin_axis_angle(coords1, axis,
+                                                           angle,
+                                                           False)
+                        coord = op.operate(coords2)
                         v1 = coord - coords1
                         v2 = coords1 - coords2
                         v3 = np.cross(v1, v2)
-                        d = np.dot(v3, axis) / np.linalg.norm(v3) / np.linalg.norm(axis)
+                        d = np.dot(v3, axis) / np.linalg.norm(v3) / \
+                            np.linalg.norm(axis)
                         if d > 1:
                             d = 1
                         elif d < -1:
                             d = -1
                         adj = math.acos(d) * 180 / math.pi
                         axis = coords1 - coords2
-                        coord = SymmOp.from_origin_axis_angle(coords1, axis, dih - adj, False).operate(coord)
+                        op = SymmOp.from_origin_axis_angle(coords1, axis,
+                                                           dih - adj, False)
+                        coord = op.operate(coord)
                         vec = coord - coords1
                         coord = vec * bl / np.linalg.norm(vec) + coords1
                         coords.append(coord)
@@ -174,11 +186,11 @@ class GaussianInput(object):
     def from_string(contents):
         """
         Creates GaussianInput from a string.
-        
+
         Args:
             contents:
                 String representing an Gaussian input file.
-        
+
         Returns:
             GaussianInput object
         """
@@ -224,18 +236,18 @@ class GaussianInput(object):
 
         return GaussianInput(mol, charge=charge, spin_multiplicity=spin_mult,
                              title=title, functional=functional,
-                            basis_set=basis_set, route_parameters=route_paras,
-                            input_parameters=input_paras)
+                             basis_set=basis_set, route_parameters=route_paras,
+                             input_parameters=input_paras)
 
     @staticmethod
     def from_file(filename):
         """
         Creates GaussianInput from a file.
-        
+
         Args:
             filename:
                 Gaussian input filename
-                
+
         Returns:
             GaussianInput object
         """
@@ -246,8 +258,9 @@ class GaussianInput(object):
         """
         Returns index of nearest neighbor atoms.
         """
-        alldist = [(self._mol.get_distance(siteindex, i), i) for i in xrange(siteindex)]
-        alldist = sorted(alldist, key=lambda x:x[0])
+        alldist = [(self._mol.get_distance(siteindex, i), i)
+                   for i in xrange(siteindex)]
+        alldist = sorted(alldist, key=lambda x: x[0])
         return [d[1] for d in alldist]
 
     def get_zmatrix(self):
@@ -262,13 +275,16 @@ class GaussianInput(object):
             elif i == 1:
                 nn = self._find_nn_pos_before_site(i)
                 bondlength = self._mol.get_distance(i, nn[0])
-                output.append("{} {} B{}".format(self._mol[i].specie, nn[0] + 1, i))
+                output.append("{} {} B{}".format(self._mol[i].specie,
+                                                 nn[0] + 1, i))
                 outputvar.append("B{}={:.6f}".format(i, bondlength))
             elif i == 2:
                 nn = self._find_nn_pos_before_site(i)
                 bondlength = self._mol.get_distance(i, nn[0])
                 angle = self._mol.get_angle(i, nn[0], nn[1])
-                output.append("{} {} B{} {} A{}".format(self._mol[i].specie, nn[0] + 1, i, nn[1] + 1, i))
+                output.append("{} {} B{} {} A{}".format(self._mol[i].specie,
+                                                        nn[0] + 1, i,
+                                                        nn[1] + 1, i))
                 outputvar.append("B{}={:.6f}".format(i, bondlength))
                 outputvar.append("A{}={:.6f}".format(i, angle))
             else:
@@ -276,7 +292,9 @@ class GaussianInput(object):
                 bondlength = self._mol.get_distance(i, nn[0])
                 angle = self._mol.get_angle(i, nn[0], nn[1])
                 dih = self._mol.get_dihedral(i, nn[0], nn[1], nn[2])
-                output.append("{} {} B{} {} A{} {} D{}".format(self._mol[i].specie, nn[0] + 1, i, nn[1] + 1, i, nn[2] + 1, i))
+                output.append("{} {} B{} {} A{} {} D{}"
+                              .format(self._mol[i].specie, nn[0] + 1, i,
+                                      nn[1] + 1, i, nn[2] + 1, i))
                 outputvar.append("B{}={:.6f}".format(i, bondlength))
                 outputvar.append("A{}={:.6f}".format(i, angle))
                 outputvar.append("D{}={:.6f}".format(i, dih))
@@ -294,7 +312,10 @@ class GaussianInput(object):
         output = []
         if self.link0_parameters:
             output.append(para_dict_to_string(self.link0_parameters, "\n"))
-        output.append("#P {func}/{bset} {route} Test".format(func=self.functional, bset=self.basis_set, route=para_dict_to_string(self.route_parameters)))
+        output.append("#P {func}/{bset} {route} Test"
+                      .format(func=self.functional, bset=self.basis_set,
+                              route=para_dict_to_string(self.route_parameters))
+                      )
         output.append("")
         output.append(self.title)
         output.append("")
@@ -312,62 +333,61 @@ class GaussianInput(object):
 class GaussianOutput(object):
     """
     Parser for Gaussian output files.
-    
+
     .. note::
-        
+
         Still in early beta.
-        
-        
+
     Attributes:
-    
+
     .. attribute:: structures
-        
+
         All structures from the calculation.
 
     .. attribute:: energies
-        
+
         All energies from the calculation.
-        
+
     .. attribute:: properly_terminated
-    
+
         True if run has properly terminated
-    
+
     .. attribute:: is_pcm
-    
+
         True if run is a PCM run.
-        
+
     .. attribute:: stationary_type
-    
+
         If it is a relaxation run, indicates whether it is a minimum (Minimum)
         or a saddle point ("Saddle").
 
     .. attribute:: corrections
-    
+
         Thermochemical corrections if this run is a Freq run as a dict. Keys
         are "Zero-point", "Thermal", "Enthalpy" and "Gibbs Free Energy"
 
     .. attribute:: functional
-        
+
         Functional used in the run.
-        
+
     .. attribute:: basis_set
-    
+
         Basis set used in the run
-        
+
     .. attribute:: charge
-    
+
         Charge for structure
-        
+
     .. attribute:: spin_mult
-    
+
         Spin multiplicity for structure
-        
+
     .. attribute:: num_basis_func
-    
+
         Number of basis functions in the run.
-        
+
     .. attribute:: pcm
-    
+
         PCM parameters and output if available.
     """
 
@@ -392,7 +412,8 @@ class GaussianOutput(object):
 
         start_patt = re.compile(" \(Enter \S+l101\.exe\)")
         route_patt = re.compile(" \#[pPnNtT]*.*")
-        charge_mul_patt = re.compile("Charge\s+=\s*([-\\d]+)\s+Multiplicity\s+=\s*(\d+)")
+        charge_mul_patt = re.compile("Charge\s+=\s*([-\\d]+)\s+"
+                                     "Multiplicity\s+=\s*(\d+)")
         num_basis_func_patt = re.compile("([0-9]+)\s+basis functions")
         pcm_patt = re.compile("Polarizable Continuum Model")
         stat_type_patt = re.compile("imaginary frequencies")
@@ -403,7 +424,8 @@ class GaussianOutput(object):
         std_orientation_patt = re.compile("Standard orientation")
         end_patt = re.compile("--+")
         orbital_patt = re.compile("Alpha\s*\S+\s*eigenvalues --(.*)")
-        thermo_patt = re.compile("(Zero-point|Thermal) correction(.*)=\s+([\d\.-]+)")
+        thermo_patt = re.compile("(Zero-point|Thermal) correction(.*)="
+                                 "\s+([\d\.-]+)")
 
         self.properly_terminated = False
         self.is_pcm = False
@@ -429,7 +451,8 @@ class GaussianOutput(object):
                         for tok in re.split("\s+", line.strip()):
                             sub_tok = tok.strip().split("=")
                             key = sub_tok[0].upper()
-                            self.route[key] = sub_tok[1].upper() if len(sub_tok) > 1 else ""
+                            self.route[key] = sub_tok[1].upper() \
+                                if len(sub_tok) > 1 else ""
                             m = re.match("(\w+)/([^/]+)", key)
                             if m:
                                 self.functional = m.group(1)
@@ -464,25 +487,29 @@ class GaussianOutput(object):
                                 for l in coord_txt[2:]:
                                     toks = re.split("\s+", l.strip())
                                     sp.append(Element.from_Z(int(toks[1])))
-                                    coords.append([float(i) for i in toks[3:6]])
+                                    coords.append([float(i)
+                                                   for i in toks[3:6]])
                                 self.structures.append(Molecule(sp, coords))
                     elif termination_patt.search(line):
                         m = termination_patt.search(line)
                         if m.group(1) == "Normal":
                             self.properly_terminated = True
                         terminated = True
-                    elif (not num_basis_found) and num_basis_func_patt.search(line):
+                    elif (not num_basis_found) and \
+                            num_basis_func_patt.search(line):
                         m = num_basis_func_patt.search(line)
                         self.num_basis_func = int(m.group(1))
                         num_basis_found = True
                     elif (not self.is_pcm) and pcm_patt.search(line):
                         self.is_pcm = True
                         self.pcm = {}
-                    elif ("FREQ" in self.route and "OPT" in self.route and stat_type_patt.search(line)):
+                    elif "FREQ" in self.route and "OPT" in self.route and \
+                            stat_type_patt.search(line):
                         self.stationary_type = "Saddle"
                     elif mp2_patt.search(line):
                         m = mp2_patt.search(line)
-                        self.energies.append(float(m.group(1).replace("D", "E")))
+                        self.energies.append(float(m.group(1).replace("D",
+                                                                      "E")))
                     elif oniom_patt.search(line):
                         m = oniom_patt.matcher(line)
                         self.energies.append(float(m.group(1)))
@@ -498,9 +525,12 @@ class GaussianOutput(object):
             raise IOError("Bad Gaussian output file.")
 
     def _check_pcm(self, line):
-        energy_patt = re.compile("(Dispersion|Cavitation|Repulsion) energy\s+\S+\s+=\s+(\S*)")
-        total_patt = re.compile("with all non electrostatic terms\s+\S+\s+=\s+(\S*)")
-        parameter_patt = re.compile("(Eps|Numeral density|RSolv|Eps\(inf[inity]*\))\s*=\s*(\S*)")
+        energy_patt = re.compile("(Dispersion|Cavitation|Repulsion) energy"
+                                 "\s+\S+\s+=\s+(\S*)")
+        total_patt = re.compile("with all non electrostatic terms\s+\S+\s+"
+                                "=\s+(\S*)")
+        parameter_patt = re.compile("(Eps|Numeral density|RSolv|Eps"
+                                    "\(inf[inity]*\))\s*=\s*(\S*)")
 
         if energy_patt.search(line):
             m = energy_patt.search(line)
