@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-'''
+"""
 This module provides classes to interface with the Materials Project http REST
 interface to enable the creation of data structures and pymatgen objects using
 Materials Project data.
@@ -8,7 +8,7 @@ Materials Project data.
 To make use of the Materials Project REST interface, you need to be a
 registered user of the MaterialsProject, and apply on the MaterialsProject site
 for an API key. Currently, the http interface is still in limited beta.
-'''
+"""
 
 from __future__ import division
 
@@ -31,11 +31,12 @@ from pymatgen.entries.exp_entries import ExpEntry
 
 class MPRester(object):
     """
-    A class to conveniently interface with the Materials Project REST interface.
+    A class to conveniently interface with the Materials Project REST
+    interface.
     """
 
-    supported_properties = ("structure", "initial_structure", "final_structure",
-                            "energy", "energy_per_atom",
+    supported_properties = ("structure", "initial_structure",
+                            "final_structure", "energy", "energy_per_atom",
                             "formation_energy_per_atom", "nsites", "formula",
                             "pretty_formula", "is_hubbard", "elements",
                             "nelements", "e_above_hull", "hubbards",
@@ -60,18 +61,19 @@ class MPRester(object):
         """
         Flexible method to get any data using the Materials Project REST
         interface. Generally used by other methods for more specific queries.
-        
+
         Format of REST return is *always* a list of dict (regardless of the
         number of pieces of data returned. The general format is as follows:
-        
-        [{'material_id': material_id, 'property_name' : value}, ...]
-        
+
+        [{"material_id": material_id, "property_name" : value}, ...]
+
         Args:
             chemsys_formula_id:
-                A chemical system (e.g., Li-Fe-O), or formula (e.g., Fe2O3) or 
+                A chemical system (e.g., Li-Fe-O), or formula (e.g., Fe2O3) or
                 materials_id (e.g., 1234).
             data_type:
-                Type of data to return. Currently can either be "vasp" or "exp".
+                Type of data to return. Currently can either be "vasp" or
+                "exp".
             prop:
                 Property to be obtained. Should be one of the
                 MPRestAdaptor.supported_properties. Leave as empty string for a
@@ -84,24 +86,24 @@ class MPRester(object):
             conn.request("GET", url, headers=headers)
             response = conn.getresponse()
             data = json.loads(response.read(), cls=PMGJSONDecoder)
-            if data['valid_response']:
-                return data['response']
+            if data["valid_response"]:
+                return data["response"]
             else:
-                raise MPRestError(data['error'])
+                raise MPRestError(data["error"])
         except httplib.HTTPException as ex:
             raise MPRestError(str(ex))
 
     def get_structure_by_material_id(self, material_id, final=True):
         """
         Get a Structure corresponding to a material_id.
-        
+
         Args:
             material_id:
                 Materials Project material_id (an int).
             final:
                 Whether to get the final structure, or the initial
                 (pre-relaxation) structure. Defaults to True.
-        
+
         Returns:
             Structure object.
         """
@@ -112,11 +114,11 @@ class MPRester(object):
     def get_entry_by_material_id(self, material_id):
         """
         Get a ComputedEntry corresponding to a material_id.
-        
+
         Args:
             material_id:
                 Materials Project material_id (an int).
-        
+
         Returns:
             ComputedEntry object.
         """
@@ -126,11 +128,11 @@ class MPRester(object):
     def get_dos_by_material_id(self, material_id):
         """
         Get a ComputedEntry corresponding to a material_id.
-        
+
         Args:
             material_id:
                 Materials Project material_id (an int).
-        
+
         Returns:
             A Dos object.
         """
@@ -140,11 +142,11 @@ class MPRester(object):
     def get_bandstructure_by_material_id(self, material_id):
         """
         Get a ComputedEntry corresponding to a material_id.
-        
+
         Args:
             material_id:
                 Materials Project material_id (an int).
-        
+
         Returns:
             A Bandstructure object.
         """
@@ -158,22 +160,22 @@ class MPRester(object):
         Li-Fe-O chemical system, i.e., all LixOy, FexOy, LixFey, LixFeyOz, Li,
         Fe and O phases. Extremely useful for creating phase diagrams of entire
         chemical systems.
-         
+
         Args:
             elements:
                 List of element symbols, e.g., ["Li", "Fe", "O"].
             compatible_only:
                 Whether to return only "compatible" entries. Compatible entries
-                are entries that have been processed using the 
+                are entries that have been processed using the
                 MaterialsProjectCompatibility class, which performs adjustments
                 to allow mixing of GGA and GGA+U calculations for more accurate
                 phase diagrams and reaction energies.
-        
+
         Returns:
             List of ComputedEntries.
         """
         data = self.get_data("-".join(elements), prop="entry")
-        entries = [d['entry'] for d in data]
+        entries = [d["entry"] for d in data]
         if compatible_only:
             entries = MaterialsProjectCompatibility().process_entries(entries)
         return entries
@@ -182,11 +184,11 @@ class MPRester(object):
         """
         Get a list of ThermoData objects associated with a formula using the
         Materials Project REST interface.
-        
+
         Args:
             formula:
                 A formula to search for.
-        
+
         Returns:
             List of ThermoData objects.
         """
@@ -196,44 +198,45 @@ class MPRester(object):
         """
         Returns an ExpEntry object, which is the experimental equivalent of a
         ComputedEntry and can be used for analyses using experimental data.
-        
+
         Args:
             formula:
                 A formula to search for.
-        
+
         Returns:
             An ExpEntry object.
         """
 
-        return ExpEntry(Composition(formula), self.get_exp_thermo_data(formula))
+        return ExpEntry(Composition(formula),
+                        self.get_exp_thermo_data(formula))
 
     def mpquery(self, criteria, properties):
         """
         Performs an advanced mpquery, which is a Mongo-like syntax for directly
         querying the Materials Project database via the mpquery rest interface.
         Please refer to the Moogle advanced help on the mpquery language and
-        supported criteria and properties. Essentially, any supported properties
-        within MPRestAdaptor should be supported in mpquery.
-        
+        supported criteria and properties. Essentially, any supported
+        properties within MPRestAdaptor should be supported in mpquery.
+
         Mpquery allows an advanced developer to perform queries which are
         otherwise too cumbersome to perform using the standard convenience
         methods.
-        
+
         Args:
             criteria:
-                Criteria of the query as a mongo-style dict. For example, 
-                {'elements':{'$in':['Li', 'Na', 'K'], '$all': ['O']},
-                'nelements':2} selects all Li, Na and K oxides
+                Criteria of the query as a mongo-style dict. For example,
+                {"elements":{"$in":["Li", "Na", "K"], "$all": ["O"]},
+                "nelements":2} selects all Li, Na and K oxides
             properties:
                 Properties to request for as a list. For example,
-                ['formula', 'formation_energy_per_atom'] returns the formula
+                ["formula", "formation_energy_per_atom"] returns the formula
                 and formation energy per atom.
-        
+
         Returns:
             List of dict of data.
         """
-        params = urllib.urlencode({'criteria': criteria,
-                                   'properties': properties})
+        params = urllib.urlencode({"criteria": criteria,
+                                   "properties": properties})
         headers = {"x-api-key": self.api_key}
         conn = httplib.HTTPSConnection(self.host)
         conn.request("POST", "/rest/mpquery", body=params, headers=headers)
@@ -243,10 +246,10 @@ class MPRester(object):
 
 
 class MPRestError(Exception):
-    '''
+    """
     Exception class for MPRestAdaptor.
     Raised when the query has problems, e.g., bad query format.
-    '''
+    """
 
     def __init__(self, msg):
         self.msg = msg
