@@ -48,12 +48,12 @@ class PDPlotter(object):
         Plot data for phase diagram.
         2-comp - Full hull with energies
         3/4-comp - Projection into 2D or 3D gibbs triangle.
-        
+
         Returns:
             (lines, stable_entries, unstable_entries):
-                - lines is a list of list of coordinates for lines in the PD. 
-                - stable_entries is a {coordinate : entry} for each stable node 
-                  in the phase diagram. (Each coordinate can only have one 
+                - lines is a list of list of coordinates for lines in the PD.
+                - stable_entries is a {coordinate : entry} for each stable node
+                  in the phase diagram. (Each coordinate can only have one
                   stable phase)
                 - unstable_entries is a {entry: coordinates} for all unstable
                   nodes in the phase diagram.
@@ -94,7 +94,8 @@ class PDPlotter(object):
                          pd.get_form_energy_per_atom(entry)]
                     coord = [x, y]
                 elif self._dim == 3:
-                    coord = triangular_coord([alldata[i, 0:2], alldata[i, 0:2]])
+                    coord = triangular_coord([alldata[i, 0:2],
+                                              alldata[i, 0:2]])
                 else:
                     coord = tet_coord([alldata[i, 0:3], alldata[i, 0:3],
                                        alldata[i, 0:3]])
@@ -116,7 +117,7 @@ class PDPlotter(object):
     def _get_2d_plot(self):
         '''
         Shows the plot using pylab.  Usually I won't do imports in methods,
-        but since plotting is a fairly expensive library to load and not all 
+        but since plotting is a fairly expensive library to load and not all
         machines have matplotlib installed, I have done it this way.
         '''
         from pymatgen.util.plotting_utils import get_publication_quality_plot
@@ -194,7 +195,7 @@ class PDPlotter(object):
     def _get_3d_plot(self):
         '''
         Shows the plot using pylab.  Usually I won't do imports in methods,
-        but since plotting is a fairly expensive library to load and not all 
+        but since plotting is a fairly expensive library to load and not all
         machines have matplotlib installed, I have done it this way.
         '''
         import matplotlib.pyplot as plt
@@ -217,9 +218,9 @@ class PDPlotter(object):
             if len(entry.composition.elements) == 1:
                 # commented out options are only for matplotlib 1.0.  Removed
                 # them so that most ppl can use this class.
-                ax.text(coords[0], coords[1], coords[2], label)#, horizontalalignment=halign, verticalalignment=valign, fontproperties=font)
+                ax.text(coords[0], coords[1], coords[2], label)
             else:
-                ax.text(coords[0], coords[1], coords[2], str(count))#, horizontalalignment=halign, verticalalignment=valign, fontproperties=font)
+                ax.text(coords[0], coords[1], coords[2], str(count))
                 newlabels.append("{} : {}".format(count, latexify(label)))
                 count += 1
         plt.figtext(0.01, 0.01, '\n'.join(newlabels))
@@ -229,12 +230,12 @@ class PDPlotter(object):
     def write_image(self, stream, image_format="svg"):
         '''
         Writes the phase diagram to an image in a stream.
-        
+
         Args:
             stream:
                 stream to write to. Can be a file stream or a StringIO stream.
             image_format
-                format for image. Can be any of matplotlib supported formats. 
+                format for image. Can be any of matplotlib supported formats.
                 Defaults to svg for best results for vector graphics.
         '''
         if self._dim < 4:
@@ -247,7 +248,6 @@ class PDPlotter(object):
 
         plt.savefig(stream, format=image_format)
 
-
     def plot_chempot_range_map(self, elements):
         """
         Plot chemical potential range map. Currently works only for 3-component
@@ -304,7 +304,10 @@ class PDPlotter(object):
         for f in facets:
             if f[0] == len(all_coords) - 1 or f[1] == len(all_coords) - 1:
                 continue
-            if (all_coords[f[0]][0] != xlim[1] or all_coords[f[1]][0] != xlim[1]) and (all_coords[f[0]][1] != ylim[1] or all_coords[f[1]][1] != ylim[1]):
+            if (all_coords[f[0]][0] != xlim[1] or
+                all_coords[f[1]][0] != xlim[1]) and \
+                (all_coords[f[0]][1] != ylim[1] or
+                 all_coords[f[1]][1] != ylim[1]):
                 excluded_boundary.append(tuple(all_coords[f[0]]))
                 excluded_boundary.append(tuple(all_coords[f[1]]))
         excluded_boundary = list(set(excluded_boundary))
@@ -314,6 +317,8 @@ class PDPlotter(object):
         y = [c[1] for c in excluded_boundary]
         plt.fill(x, y, '0.80')
 
+        el0 = elements[0]
+        el1 = elements[1]
         for entry, coords in missing_lines.items():
             center_x = 0
             center_y = 0
@@ -322,10 +327,10 @@ class PDPlotter(object):
                 for coord in coords:
                     x = None
                     y = None
-                    if entry.composition.get_atomic_fraction(elements[0]) < 0.01:
+                    if entry.composition.get_atomic_fraction(el0) < 0.01:
                         x = [coord[0], min(xlim)]
                         y = [coord[1], coord[1]]
-                    elif entry.composition.get_atomic_fraction(elements[1]) < 0.01:
+                    elif entry.composition.get_atomic_fraction(el1) < 0.01:
                         x = [coord[0], coord[0]]
                         y = [coord[1], min(ylim)]
                     if x and y:
@@ -336,11 +341,14 @@ class PDPlotter(object):
                 center_x = sum(coord[0] for coord in coords) * 2 + xlim[0]
                 center_y = sum(coord[1] for coord in coords) * 2 + ylim[0]
             xy = (center_x / 2 / len(coords), center_y / 2 / len(coords))
-            plt.annotate(latexify(entry.name), xy, horizontalalignment="center",
+            plt.annotate(latexify(entry.name), xy,
+                         horizontalalignment="center",
                          verticalalignment="center", fontsize=22)
 
-        plt.xlabel("$\mu_{{{0}}} - \mu_{{{0}}}^0$ (eV)".format(elements[0].symbol))
-        plt.ylabel("$\mu_{{{0}}} - \mu_{{{0}}}^0$ (eV)".format(elements[1].symbol))
+        plt.xlabel("$\mu_{{{0}}} - \mu_{{{0}}}^0$ (eV)"
+                   .format(el0.symbol))
+        plt.ylabel("$\mu_{{{0}}} - \mu_{{{0}}}^0$ (eV)"
+                   .format(el1.symbol))
         plt.tight_layout()
         plt.show()
 
@@ -349,12 +357,12 @@ def uniquelines(q):
     '''
     Given all the facets, convert it into a set of unique lines.  Specifically
     used for converting convex hull facets into line pairs of coordinates.
-    
+
     Args:
         q:
-            A 2-dim sequence, where each row represents a facet. E.g., 
+            A 2-dim sequence, where each row represents a facet. E.g.,
             [[1,2,3],[3,6,7],...]
-    
+
     Returns:
         setoflines:
             A set of tuple of lines.  E.g., ((1,2), (1,3), (2,3), ....)
@@ -370,29 +378,30 @@ def triangular_coord(coord):
     '''
     Convert a 2D coordinate into a triangle-based coordinate system for a
     prettier phase diagram.
-    
+
     Args:
         coordinate:
             coordinate used in the convex hull computation.
-    
+
     Returns:
-        coordinates in a triangular-based coordinate system. 
+        coordinates in a triangular-based coordinate system.
     '''
     unitvec = np.array([[1, 0], [0.5, math.sqrt(3) / 2]])
     result = np.dot(np.array(coord), unitvec)
     return result.transpose()
 
+
 def tet_coord(coord):
     '''
     Convert a 3D coordinate into a tetrahedron based coordinate system for a
     prettier phase diagram.
-    
+
     Args:
         coordinate:
             coordinate used in the convex hull computation.
-    
+
     Returns:
-        coordinates in a tetrahedron-based coordinate system. 
+        coordinates in a tetrahedron-based coordinate system.
     '''
     unitvec = np.array([[1, 0, 0], [0.5, math.sqrt(3) / 2, 0],
                         [0.5, 1.0 / 3.0 * math.sqrt(3) / 2, math.sqrt(6) / 3]])
