@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 
-'''
-This module defines site transformations which transforms a structure into 
-another structure. Site transformations differ from standard transformations 
+"""
+This module defines site transformations which transforms a structure into
+another structure. Site transformations differ from standard transformations
 in that they operate in a site-specific manner.
 All transformations should inherit the AbstractTransformation ABC.
-'''
+"""
 
 from __future__ import division
 
@@ -62,7 +62,8 @@ class InsertSitesTransformation(AbstractTransformation):
         return editor.modified_structure.get_sorted_structure()
 
     def __str__(self):
-        return "InsertSiteTransformation : species {}, coords {}".format(self._species, self._coords)
+        return "InsertSiteTransformation : " + \
+            "species {}, coords {}".format(self._species, self._coords)
 
     def __repr__(self):
         return self.__str__()
@@ -77,12 +78,12 @@ class InsertSitesTransformation(AbstractTransformation):
 
     @property
     def to_dict(self):
-        d = {'name' : self.__class__.__name__, 'version': __version__}
-        d['init_args'] = {'species': self._species, 'coords': self._coords,
-                          'coords_are_cartesian':self._cartesian,
-                          'validate_proximity': self._validate_proximity}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
+        d = {"name": self.__class__.__name__, "version": __version__}
+        d["init_args"] = {"species": self._species, "coords": self._coords,
+                          "coords_are_cartesian": self._cartesian,
+                          "validate_proximity": self._validate_proximity}
+        d["module"] = self.__class__.__module__
+        d["class"] = self.__class__.__name__
         return d
 
 
@@ -94,11 +95,12 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         """
         Args:
             indices_species_map:
-                A dict containing the species mapping in int-string pairs. 
-                E.g., { 1:"Na"} or {2:"Mn2+"}. Multiple substitutions can 
+                A dict containing the species mapping in int-string pairs.
+                E.g., { 1:"Na"} or {2:"Mn2+"}. Multiple substitutions can
                 be done. Overloaded to accept sp_and_occu dictionary
-                E.g. {'Si: {'Ge':0.75, 'C':0.25} }, which substitutes a single
-                species with multiple species to generate a disordered structure.
+                E.g. {"Si: {"Ge":0.75, "C":0.25} }, which substitutes a single
+                species with multiple species to generate a disordered
+                structure.
         """
         self._indices_species_map = indices_species_map
 
@@ -109,7 +111,8 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         return editor.modified_structure
 
     def __str__(self):
-        return "ReplaceSiteSpeciesTransformation :" + ", ".join([k + "->" + v for k, v in self._species_map.items()])
+        return "ReplaceSiteSpeciesTransformation :" + \
+            ", ".join([k + "->" + v for k, v in self._species_map.items()])
 
     def __repr__(self):
         return self.__str__()
@@ -124,10 +127,10 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
 
     @property
     def to_dict(self):
-        d = {'name' : self.__class__.__name__, 'version': __version__}
-        d['init_args'] = {'indices_species_map': self._indices_species_map}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
+        d = {"name": self.__class__.__name__, "version": __version__}
+        d["init_args"] = {"indices_species_map": self._indices_species_map}
+        d["module"] = self.__class__.__module__
+        d["class"] = self.__class__.__name__
         return d
 
 
@@ -139,7 +142,7 @@ class RemoveSitesTransformation(AbstractTransformation):
         """
         Args:
             indices_to_remove:
-                List of indices to remove. E.g., [0, 1, 2] 
+                List of indices to remove. E.g., [0, 1, 2]
         """
         self._indices = indices_to_remove
 
@@ -164,10 +167,10 @@ class RemoveSitesTransformation(AbstractTransformation):
 
     @property
     def to_dict(self):
-        d = {'name' : self.__class__.__name__, 'version': __version__}
-        d['init_args'] = {'indices_to_remove': self._indices}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
+        d = {"name": self.__class__.__name__, "version": __version__}
+        d["init_args"] = {"indices_to_remove": self._indices}
+        d["module"] = self.__class__.__module__
+        d["class"] = self.__class__.__name__
         return d
 
 
@@ -175,7 +178,19 @@ class TranslateSitesTransformation(AbstractTransformation):
     """
     This class translates a set of sites by a certain vector.
     """
-    def __init__(self, indices_to_move, translation_vector, vector_in_frac_coords=True):
+    def __init__(self, indices_to_move, translation_vector,
+                 vector_in_frac_coords=True):
+        """
+        Args:
+            indices_to_move:
+                The indices of the sites to move
+            translation_vector:
+                Vector to move the sites.
+            vector_in_frac_coords:
+                Set to True if the translation vector is in fractional
+                coordinates, and False if it is in cartesian coordinations.
+                Defaults to True.
+        """
         self._indices = indices_to_move
         self._vector = translation_vector
         self._frac = vector_in_frac_coords
@@ -187,7 +202,7 @@ class TranslateSitesTransformation(AbstractTransformation):
 
     def __str__(self):
         return "TranslateSitesTransformation for indices " + \
-            "{}, vector {} and vector_in_frac_coords = {}".format(self._indices,
+            "{}, vect {} and vect_in_frac_coords = {}".format(self._indices,
                                         self._translation_vector, self._frac)
 
     def __repr__(self):
@@ -205,46 +220,46 @@ class TranslateSitesTransformation(AbstractTransformation):
 
     @property
     def to_dict(self):
-        d = {'name' : self.__class__.__name__, 'version': __version__}
-        d['init_args'] = {'indices_to_move': self._indices,
-                               'translation_vector': self._vector,
-                               'vector_in_frac_coords': self._frac}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
+        d = {"name": self.__class__.__name__, "version": __version__}
+        d["init_args"] = {"indices_to_move": self._indices,
+                               "translation_vector": self._vector,
+                               "vector_in_frac_coords": self._frac}
+        d["module"] = self.__class__.__module__
+        d["class"] = self.__class__.__name__
         return d
 
 
 class PartialRemoveSitesTransformation(AbstractTransformation):
     """
-    Remove fraction of specie from a structure. 
-    Requires an oxidation state decorated structure for ewald sum to be 
+    Remove fraction of specie from a structure.
+    Requires an oxidation state decorated structure for ewald sum to be
     computed.
-    
+
     Given that the solution to selecting the right removals is NP-hard, there
     are several algorithms provided with varying degrees of accuracy and speed.
     The options are as follows:
-    
+
     ALGO_FAST:
-        This is a highly optimized algorithm to quickly go through the search 
+        This is a highly optimized algorithm to quickly go through the search
         tree. It is guaranteed to find the optimal solution, but will return
         only a single lowest energy structure. Typically, you will want to use
         this.
-    
+
     ALGO_COMPLETE:
-        The complete algo ensures that you get all symmetrically distinct 
+        The complete algo ensures that you get all symmetrically distinct
         orderings, ranked by the estimated Ewald energy. But this can be an
         extremely time-consuming process if the number of possible orderings is
         very large. Use this if you really want all possible orderings. If you
         want just the lowest energy ordering, ALGO_FAST is accurate and faster.
-        
+
     ALGO_BEST_FIRST:
-        This algorithm is for ordering the really large cells that defeats even 
+        This algorithm is for ordering the really large cells that defeats even
         ALGO_FAST.  For example, if you have 48 sites of which you want to
-        remove 16 of them, the number of possible orderings is around 2 x 10^12.
-        ALGO_BEST_FIRST shortcircuits the entire search tree by removing the 
-        highest energy site first, then followed by the next highest energy
-        site, and so on.  It is guaranteed to find a solution in a reasonable
-        time, but it is also likely to be highly inaccurate. 
+        remove 16 of them, the number of possible orderings is around
+        2 x 10^12. ALGO_BEST_FIRST shortcircuits the entire search tree by
+        removing the highest energy site first, then followed by the next
+        highest energy site, and so on. It is guaranteed to find a solution
+        in a reasonable time, but it is also likely to be highly inaccurate.
     """
 
     ALGO_FAST = 0
@@ -271,27 +286,29 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         self.logger = logging.getLogger(self.__class__.__name__)
 
     def best_first_ordering(self, structure, num_remove_dict):
-        self.logger.debug('Performing best first ordering')
+        self.logger.debug("Performing best first ordering")
         starttime = time.time()
-        self.logger.debug('Performing initial ewald sum...')
+        self.logger.debug("Performing initial ewald sum...")
         ewaldsum = EwaldSummation(structure)
-        self.logger.debug('Ewald sum took {} seconds.'.format(time.time() - starttime))
+        self.logger.debug("Ewald sum took {} seconds."
+                          .format(time.time() - starttime))
         starttime = time.time()
 
         ematrix = ewaldsum.total_energy_matrix
         to_delete = []
 
         totalremovals = sum(num_remove_dict.values())
-        removed = {k : 0 for k in num_remove_dict.keys()}
+        removed = {k: 0 for k in num_remove_dict.keys()}
         for i in xrange(totalremovals):
             maxindex = None
-            maxe = float('-inf')
+            maxe = float("-inf")
             maxindices = None
             for indices in num_remove_dict.keys():
                 if removed[indices] < num_remove_dict[indices]:
                     for ind in indices:
                         if ind not in to_delete:
-                            energy = sum(ematrix[:, ind]) + sum(ematrix[:, ind]) - ematrix[ind, ind]
+                            energy = sum(ematrix[:, ind]) + \
+                                sum(ematrix[:, ind]) - ematrix[ind, ind]
                             if energy > maxe:
                                 maxindex = ind
                                 maxe = energy
@@ -302,23 +319,26 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             ematrix[maxindex, :] = 0
         mod = StructureEditor(structure)
         mod.delete_sites(to_delete)
-        self.logger.debug('Minimizing Ewald took {} seconds.'.format(time.time() - starttime))
-        return [{'energy':sum(sum(ematrix)),
-                 'structure': mod.modified_structure.get_sorted_structure()}]
+        self.logger.debug("Minimizing Ewald took {} seconds."
+                          .format(time.time() - starttime))
+        return [{"energy":sum(sum(ematrix)),
+                 "structure": mod.modified_structure.get_sorted_structure()}]
 
     def complete_ordering(self, structure, num_remove_dict):
-        self.logger.debug('Performing complete ordering...')
+        self.logger.debug("Performing complete ordering...")
         all_structures = []
-        from pymatgen.symmetry.spglib_adaptor import SymmetryFinder
+        from pymatgen.symmetry.finder import SymmetryFinder
         symprec = 0.2
         s = SymmetryFinder(structure, symprec=symprec)
-        self.logger.debug('Symmetry of structure is determined to be {}.'.format(s.get_spacegroup_symbol()))
+        self.logger.debug("Symmetry of structure is determined to be {}."
+                          .format(s.get_spacegroup_symbol()))
         sg = s.get_spacegroup()
         tested_sites = []
         starttime = time.time()
-        self.logger.debug('Performing initial ewald sum...')
+        self.logger.debug("Performing initial ewald sum...")
         ewaldsum = EwaldSummation(structure)
-        self.logger.debug('Ewald sum took {} seconds.'.format(time.time() - starttime))
+        self.logger.debug("Ewald sum took {} seconds."
+                          .format(time.time() - starttime))
         starttime = time.time()
 
         allcombis = []
@@ -339,51 +359,57 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             energy = ewaldsum.compute_partial_energy(indices_list)
             already_tested = False
             for i, tsites in enumerate(tested_sites):
-                tenergy = all_structures[i]['energy']
+                tenergy = all_structures[i]["energy"]
                 if abs((energy - tenergy) / len(s_new)) < 1e-5 and \
                    sg.are_symmetrically_equivalent(sites_to_remove, tsites,
-                                                   symprec=symprec):
+                                                   symm_prec=symprec):
                     already_tested = True
 
             if not already_tested:
                 tested_sites.append(sites_to_remove)
-                all_structures.append({'structure':s_new, 'energy':energy})
+                all_structures.append({"structure": s_new, "energy": energy})
 
             count += 1
             if count % 10 == 0:
                 timenow = time.time()
-                self.logger.debug('{} structures, {:.2f} seconds.'.format(count, timenow - starttime))
-                self.logger.debug('Average time per combi = {} seconds'.format((timenow - starttime) / count))
-                self.logger.debug('{} symmetrically distinct structures found.'.format(len(all_structures)))
+                self.logger.debug("{} structures, {:.2f} seconds."
+                                  .format(count, timenow - starttime))
+                self.logger.debug("Average time per combi = {} seconds"
+                                  .format((timenow - starttime) / count))
+                self.logger.debug("{} symmetrically distinct structures found."
+                                  .format(len(all_structures)))
 
-        self.logger.debug('Total symmetrically distinct structures found = {}'.format(len(all_structures)))
-        all_structures = sorted(all_structures, key=lambda s: s['energy'])
+        self.logger.debug("Total symmetrically distinct structures found = {}"
+                          .format(len(all_structures)))
+        all_structures = sorted(all_structures, key=lambda s: s["energy"])
         return all_structures
 
     def fast_ordering(self, structure, num_remove_dict, num_to_return=1):
         """
-        This method uses the matrix form of ewaldsum to calculate the ewald sums 
-        of the potential structures. This is on the order of 4 orders of magnitude 
-        faster when there are large numbers of permutations to consider.
-        There are further optimizations possible (doing a smarter search of 
-        permutations for example), but this wont make a difference
+        This method uses the matrix form of ewaldsum to calculate the ewald
+        sums of the potential structures. This is on the order of 4 orders of
+        magnitude faster when there are large numbers of permutations to
+        consider. There are further optimizations possible (doing a smarter
+        search of permutations for example), but this wont make a difference
         until the number of permutations is on the order of 30,000.
         """
-        self.logger.debug('Performing fast ordering')
+        self.logger.debug("Performing fast ordering")
         starttime = time.time()
-        self.logger.debug('Performing initial ewald sum...')
+        self.logger.debug("Performing initial ewald sum...")
 
         ewaldmatrix = EwaldSummation(structure).total_energy_matrix
-        self.logger.debug('Ewald sum took {} seconds.'.format(time.time() - starttime))
+        self.logger.debug("Ewald sum took {} seconds."
+                          .format(time.time() - starttime))
         starttime = time.time()
         m_list = []
         for indices, num in num_remove_dict.items():
             m_list.append([0, num, list(indices), None])
 
-        self.logger.debug('Calling EwaldMinimizer...')
+        self.logger.debug("Calling EwaldMinimizer...")
         minimizer = EwaldMinimizer(ewaldmatrix, m_list, num_to_return,
                                    PartialRemoveSitesTransformation.ALGO_FAST)
-        self.logger.debug('Minimizing Ewald took {} seconds.'.format(time.time() - starttime))
+        self.logger.debug("Minimizing Ewald took {} seconds."
+                          .format(time.time() - starttime))
 
         all_structures = []
 
@@ -392,7 +418,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
         for output in minimizer.output_lists:
             se = StructureEditor(structure)
-            del_indices = [] #do deletions afterwards because they screw up the indices of the structure
+            del_indices = []
 
             for manipulation in output[1]:
                 if manipulation[1] is None:
@@ -400,16 +426,19 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                 else:
                     se.replace_site(manipulation[0], manipulation[1])
             se.delete_sites(del_indices)
-            all_structures.append({'energy':output[0],
-             'energy_above_minimum':(output[0] - lowest_energy) / num_atoms,
-             'structure': se.modified_structure.get_sorted_structure()})
+            struct = se.modified_structure.get_sorted_structure()
+            all_structures.append({"energy": output[0],
+                                   "energy_above_minimum": (output[0]
+                                                            - lowest_energy)
+                                   / num_atoms,
+                                   "structure": struct})
 
         return all_structures
 
     def apply_transformation(self, structure, return_ranked_list=False):
         """
         Apply the transformation.
-        
+
         Args:
             structure:
                 input structure
@@ -417,17 +446,17 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                 Boolean stating whether or not multiple structures are
                 returned. If return_ranked_list is a number, that number of
                 structures is returned.
-                
+
         Returns:
-            Depending on returned_ranked list, either a transformed structure 
+            Depending on returned_ranked list, either a transformed structure
             or
-            a list of dictionaries, where each dictionary is of the form 
-            {'structure' = .... , 'other_arguments'}
-            the key 'transformation' is reserved for the transformation that
-            was actually applied to the structure. 
+            a list of dictionaries, where each dictionary is of the form
+            {"structure" = .... , "other_arguments"}
+            the key "transformation" is reserved for the transformation that
+            was actually applied to the structure.
             This transformation is parsed by the alchemy classes for generating
             a more specific transformation history. Any other information will
-            be stored in the transformation_parameters dictionary in the 
+            be stored in the transformation_parameters dictionary in the
             transmuted structure class.
         """
         num_remove_dict = {}
@@ -435,14 +464,17 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         for indices, frac in zip(self._indices, self._fractions):
             num_to_remove = len(indices) * frac
             if abs(num_to_remove - int(round(num_to_remove))) > 1e-3:
-                raise ValueError("Fraction to remove must be consistent with integer amounts in structure.")
+                raise ValueError("Fraction to remove must be consistent with "
+                                 "integer amounts in structure.")
             else:
                 num_to_remove = int(round(num_to_remove))
             num_remove_dict[tuple(indices)] = num_to_remove
             n = len(indices)
-            total_combis += int(round(math.factorial(n) / math.factorial(num_to_remove) / math.factorial(n - num_to_remove)))
+            total_combis += int(round(math.factorial(n) /
+                                      math.factorial(num_to_remove) /
+                                      math.factorial(n - num_to_remove)))
 
-        self.logger.debug('Total combinations = {}'.format(total_combis))
+        self.logger.debug("Total combinations = {}".format(total_combis))
 
         try:
             num_to_return = int(return_ranked_list)
@@ -450,22 +482,26 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             num_to_return = 1
 
         num_to_return = max(1, num_to_return)
-        self.logger.debug('Will return {} best structures.'.format(num_to_return))
+        self.logger.debug("Will return {} best structures."
+                          .format(num_to_return))
 
         if self._algo == PartialRemoveSitesTransformation.ALGO_FAST:
-            all_structures = self.fast_ordering(structure, num_remove_dict, num_to_return)
+            all_structures = self.fast_ordering(structure, num_remove_dict,
+                                                num_to_return)
         elif self._algo == PartialRemoveSitesTransformation.ALGO_COMPLETE:
             all_structures = self.complete_ordering(structure, num_remove_dict)
         elif self._algo == PartialRemoveSitesTransformation.ALGO_BEST_FIRST:
-            all_structures = self.best_first_ordering(structure, num_remove_dict)
-        opt_s = all_structures[0]['structure']
-        return opt_s if not return_ranked_list else all_structures[0:num_to_return]
+            all_structures = self.best_first_ordering(structure,
+                                                      num_remove_dict)
+        opt_s = all_structures[0]["structure"]
+        return opt_s if not return_ranked_list \
+            else all_structures[0:num_to_return]
 
     def __str__(self):
-        return "PartialRemoveSitesTransformation : Indices and fraction to " + \
-               "remove = {}, ALGO = {}".format(self._specie,
-                                            self._indices_fraction_dict,
-                                            self._algo)
+        return "PartialRemoveSitesTransformation : Indices and fraction" + \
+               " to remove = {}, ALGO = {}".format(self._specie,
+                                                   self._indices_fraction_dict,
+                                                   self._algo)
 
     def __repr__(self):
         return self.__str__()
@@ -480,10 +516,9 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
     @property
     def to_dict(self):
-        d = {'name' : self.__class__.__name__, 'version': __version__}
-        d['init_args'] = {'indices': self._indices,
-                          'fractions': self._fractions, 'algo':self._algo}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
+        d = {"name": self.__class__.__name__, "version": __version__}
+        d["init_args"] = {"indices": self._indices,
+                          "fractions": self._fractions, "algo": self._algo}
+        d["module"] = self.__class__.__module__
+        d["class"] = self.__class__.__name__
         return d
-
