@@ -24,19 +24,19 @@ def file_open_zip_aware(filename, *args, **kwargs):
     .. deprecated:: 2.1.0
         This function has been renamed to the much shorter :func:`zopen`. It
         will be removed in future versions.
-        
-    This wrapper wraps around the bz2, gzip and standard python's open function 
+
+    This wrapper wraps around the bz2, gzip and standard python's open function
     to deal intelligently with bzipped, gzipped or standard text files.
-    
+
     Args:
         filename:
-            filename 
+            filename
         args:
             Standard args for python open(..). E.g., 'r' for read, 'w' for
             write.
         kwargs:
             Standard kwargs for python open(..).
-            
+
     Returns:
         File handler
     """
@@ -45,18 +45,18 @@ def file_open_zip_aware(filename, *args, **kwargs):
 
 def zopen(filename, *args, **kwargs):
     """
-    This wrapper wraps around the bz2, gzip and standard python's open function 
+    This wrapper wraps around the bz2, gzip and standard python's open function
     to deal intelligently with bzipped, gzipped or standard text files.
-    
+
     Args:
         filename:
-            filename 
+            filename
         args:
             Standard args for python open(..). E.g., 'r' for read, 'w' for
             write.
         kwargs:
             Standard kwargs for python open(..).
-            
+
     Returns:
         File handler
     """
@@ -72,13 +72,13 @@ def zopen(filename, *args, **kwargs):
 def clean_lines(string_list, remove_empty_lines=True):
     """
     Strips whitespace, \n and \r and empty lines from a list.
-    
+
     Args:
         string_list:
             List of strings
         remove_empty_lines:
             Set to True to skip lines which are empty after stripping.
-    
+
     Returns:
         List of clean strings with no whitespaces.
     """
@@ -96,28 +96,32 @@ def clean_lines(string_list, remove_empty_lines=True):
 def micro_pyawk(filename, search, results=None, debug=None, postdebug=None):
     """
     Small awk-mimicking search routine.
-       
+
     'file' is file to search through.
-    'search' is the "search program", a list of lists/tuples with 3 elements; i.e.
-    [[regex,test,run],[regex,test,run],...]
-    'results' is a an object that your search program will have access to for storing results.
+    'search' is the "search program", a list of lists/tuples with 3 elements;
+    i.e. [[regex,test,run],[regex,test,run],...]
+    'results' is a an object that your search program will have access to for
+    storing results.
 
-    Here regex is either as a Regex object, or a string that we compile into a Regex.
-    test and run are callable objects.
+    Here regex is either as a Regex object, or a string that we compile into a
+    Regex. test and run are callable objects.
+
+    This function goes through each line in filename, and if regex matches that
+    line *and* test(results,line)==True (or test == None) we execute
+    run(results,match),where match is the match object from running
+    Regex.match.
+
+    The default results is an empty dictionary. Passing a results object let
+    you interact with it in run() and test(). Hence, in many occasions it is
+    thus clever to use results=self.
 
-    This function goes through each line in filename, and if regex matches that line *and* 
-    test(results,line)==True (or test == None) we execute run(results,match), 
-    where match is the match object from running Regex.match.   
-    
-    The default results is an empty dictionary. Passing a results object let you interact 
-    with it in run() and test(). Hence, in many occasions it is thus clever to use results=self. 
-    
     Author: Rickard Armiento
-    
-    Returns: 
+
+    Returns:
         results
     """
-    if results == None: results = {}
+    if results is None:
+        results = {}
 
     # Compile strings into regexs
     for entry in search:
@@ -138,12 +142,13 @@ def micro_pyawk(filename, search, results=None, debug=None, postdebug=None):
     reader.close()
     return results
 
+
 def clean_json(input_json, strict=False):
     """
     This method cleans an input json-like dict object, either a list or a dict,
     nested or otherwise, by converting all non-string dictionary keys (such as
     int and float) to strings.
-    
+
     Args:
         input_dict:
             input dictionary.
@@ -152,16 +157,17 @@ def clean_json(input_json, strict=False):
             object it does not understand. If strict is True, clean_json will
             try to get the to_dict attribute of the object. If no such
             attribute is found, an attribute error will be thrown. If strict is
-            False, clean_json will simply call str(object) to convert the object
-            to a string representation.
-    
+            False, clean_json will simply call str(object) to convert the
+            object to a string representation.
+
     Returns:
         Sanitized dict that can be json serialized.
     """
     if isinstance(input_json, (list, numpy.ndarray)):
         return [clean_json(i, strict=strict) for i in input_json]
     elif isinstance(input_json, dict):
-        return {str(k): clean_json(v, strict=strict) for k, v in input_json.items()}
+        return {str(k): clean_json(v, strict=strict)
+                for k, v in input_json.items()}
     elif isinstance(input_json, (int, float)):
         return input_json
     else:
